PROC GLOBAL

{ --------------------------------------------------------------------------- }

set explicit;
{ Working variables }
array alpha(8) KishGrid(10);
alpha(26) alphavar;
alpha(26) alphanew;
array codes(50);
array alpha(50) labels(50);
array wenter(50); 	{ Working var recording entry of individuals }
array wcomp (50); 	{ Working var recording completeness of individuals }

{ for Birth history checks }
array twincode(20); { For checking twins }
array ldc(20);		{ Lower bound of date of birth of child }
array udc(20);		{ Upper bound of date of birth of child }
numeric adeath, inEntry, lb, ldb, maxchild, maxd, mind, prev;
{end of defining variables for birth history checks}

numeric zscoeff zsr zsb1 zsb2 zsb3 zsb4 zsb5 zsdz zst
  zsdzp zsfx zsll zsul zsa zsknot zsi zsj zsk zsl
  zsz zsc zsy1 zsy2 zsy3 zssd1 zssd2 zshta
  zspmed zsv zshac zshap zshaz zswap zswaz zswac zshtw
  zswhp zswhz zswhc fhaz fwaz fwhz zsflag leapday
  xdays1 xdays2
  vcheckx addmode qmark totlen aok alphsize
  maxmem maxnet hhnum
  wminage wmaxage minab minam
  mminage mmaxage mminab mminam
  chhlth chlabl chlabu mindi cln err dd ss ddw ddm
  di diwm dich dimn xline xwomen xchild xmen xmc
  udob ldob ldobfc udobfc ldoblc udoblc ldofm udofm
  hwsex hwage hwerr birthd birthm birthy age xweight xheight
  lastdig
  a e i j l lx n t x y found net
  xwc xcc cdline kount opid;

{ --------------------------------------------------------------------------- }
{ valid
  Checks that a variable has a valid value.
  A valid value is less than 96 and not a special value e.g notappl/missing
  Returns: 1 if valid, 0 if not valid                                        }

function valid(xvar);
  valid = (!special(xvar) and xvar < 96)
end;

{ -------------------------------------------------------------------------- }
{ NAtoZero
  Converts notappl (and 99 - for child labour module) values to zero while not changing other values.
  Returns: 0 if input variable is notappl, else returns it unchanged         }
function NAtoZero(xvar);
  if xvar = notappl or xvar=99 then
    xvar = 0
  endif;
  NAtoZero = xvar;
end;

{ -------------------------------------------------------------------------- }
{ noteq
  Tests for inequality, but treating NA as zero                              }

  function noteq( xvar, dvar );
    noteq = (xvar <> NAtoZero(dvar));
  end;

{ -------------------------------------------------------------------------- }
{ Birth History functions }

{ --------------------------------------------------------------------------- }
{ validyr
  Checks that a 4 digit variable has a valid value.
  A valid value is less than 9996 and not a special value e.g notappl/missing
  Returns: 1 if valid, 0 if not valid                                        }

  function validyr(xvar);
    validyr = (!special(xvar) and xvar < 9996)
  end;

{ -------------------------------------------------------------------------- }
{ afterint
  to check that no date is after the date of interview                       }
  function afterint( vcheckm, vchecky );
    x = 0;
    if validyr(vchecky) & vchecky > WM6Y |
       vchecky = WM6Y & valid(vcheckm) & vcheckm > WM6M then
      x = 1
    endif;
    afterint = x;
  end;

{ -------------------------------------------------------------------------- }
{ ndjlba
  Revised function to adjust dates based on age                              }
  function ndjlba(lowera,uppera,lowerb,upperb,agetofit)
    { calculate new possible lower bound for a = lower bound of b - age - 12 months }
    x = lowerb - 12 * (agetofit + 1);
    { if new lower bound > upper bound then we have an inconsistency }
    if x > uppera then
      x = -1
    else
      { if new lower bound is less than upper bound, change new lower bound to be
        lower bound of b - age - 11 months }
      if x < uppera then
        x = x + 1
      endif;
      { if new lower bound is less than old lower bound for a, leave with old value }
      if lowera > x then
        x = lowera
      endif
    endif;
    { return value of lower bound of a }
    ndjlba = x
  end;

{ -------------------------------------------------------------------------- }
{ badspecial
  Check special answers for questions with units and numbers
  !!! make sure to correctly adjust the ranges of the
      questions involved, for the function to work properly                  }
  function badspecial( units, number )
    x = 0;
    if (units  = 9 & number <= 90) |
       (units <> 9 & number in 90:98) |
       (units  > 1 & number = 0  ) then
      x = 1;
    endif;
    badspecial = x;
  end;

{ -------------------------------------------------------------------------- }
{ ITN functions }
function clear_labels();
  do i = 1 while i <= 50
    codes(i) = notappl;
    labels(i) = "";
  enddo;
end;

function setnet(alpha(8) xvarname, curnet);
  clear_labels();
  n = tonumber(xvarname[length(strip(xvarname)):1]);  { Gets the TN11_x number, e.g. TN11_2 returns 2 }
  x = 0;
  codes(x) = 0;
  labels(x) = {+EN} "Not in household list"; {EN+}
              {{FR} "Pas dans le mnage"; {FR}}
              {{ES} "ES"; {ES}}
  for i in FORMHL_ROSTER do
    found = 0;
    do net = 1 while !found & net <= curnet
      if !found & (net < curnet | n > 1) & TN12_1(net) = i then found = 1 endif;
      if !found & (net < curnet | n > 2) & TN12_2(net) = i then found = 1 endif;
      if !found & (net < curnet | n > 3) & TN12_3(net) = i then found = 1 endif;
      if !found & (net < curnet        ) & TN12_4(net) = i then found = 1 endif;
    enddo;
    if !found then
      x = x + 1;
      codes(x) = i;
      labels(x) = edit("99",i);
    endif;
  enddo;
  if n <> 1 then { First person - cannot be "90" }
    x = x + 1;
    codes(x) = 90;
    labels(x) = {+EN} "No one else"; {EN+}
                {{FR} "Personne d'autre"; {FR}}
                {{ES} "ES"; {ES}}
  endif;
end;

function checknet(xvar, alpha(8) xvarname, curnet);
  e = 0;
  n = tonumber(xvarname[length(strip(xvarname)):1]);  { Gets the TN12_x number, e.g. TN12_2 returns 2 }
  if xvar = 90 then
    if n = 1 & TN11 = 1 then
      e=errmsg(2808);
    endif;
  elseif xvar < 90 then
    if xvar > HH11 then	{ Greater than number of HH members }
      e=errmsg(2806,xvar,HH11);
    else
      { Is member already listed, possibly under another net }
      found = 0;
      if xvar <> 0 then
        do net = 1 while !found & net <= curnet
          if !found & (net < curnet | n < 1) & TN12_1(net) = xvar then found = 1 endif;
          if !found & (net < curnet | n < 2) & TN12_2(net) = xvar then found = 1 endif;
          if !found & (net < curnet | n < 3) & TN12_3(net) = xvar then found = 1 endif;
          if !found & (net < curnet | n < 4) & TN12_4(net) = xvar then found = 1 endif;
        enddo;
      endif;
      if found then
        e=errmsg(2807,xvar);
      endif;
      { check if person slept in HH last night }
      if xvar <> 0 then
       if HL10(xvar) <> 1 then
         e=errmsg(2809,xvar,HL10(xvar));
       endif;
      endif;
    endif;
  endif;
  checknet = e;
end;

{ -------------------------------------------------------------------------- }
{ Anthropometry function         }
{ Height and Weight Z-score functions }

function zscoef(zsip,zsjp,zskp,zslp);
  recode zsip:zsjp:zskp:zslp => zscoeff;
 1:1:1:1=> 0.461824*100    ;  1:1:1:2=> 0.401257*10     ;  1:1:1:3=>-0.255449        ;  1:1:1:4=> 0.789966*0.01   ;
 1:1:2:1=> 0.673630*100    ;  1:1:2:2=> 0.133410*10     ;  1:1:2:3=>-0.421583*0.1    ;  1:1:2:4=> 0.101581*0.01   ;
 1:1:3:1=> 0.813173*100    ;  1:1:3:2=> 0.755023        ;  1:1:3:3=> 0.355289*0.01   ;  1:1:3:4=>-0.590137*0.001  ;
 1:2:1:1=> 0.504849*100    ;  1:2:1:2=> 0.438155*10     ;  1:2:1:3=>-0.312088        ;  1:2:1:4=> 0.105514*0.1    ;
 1:2:2:1=> 0.723318*100    ;  1:2:2:2=> 0.132797*10     ;  1:2:2:3=>-0.271990*0.1    ;  1:2:2:4=> 0.448522*0.001  ;
 1:2:3:1=> 0.876453*100    ;  1:2:3:2=> 0.814752        ;  1:2:3:3=>-0.701552*0.01   ;  1:2:3:4=> 0.609604*0.0001 ;
 1:3:1:1=> 0.547862*100    ;  1:3:1:2=> 0.475220*10     ;  1:3:1:3=>-0.368845        ;  1:3:1:4=> 0.132042*0.1    ;
 1:3:2:1=> 0.773055*100    ;  1:3:2:2=> 0.132163*10     ;  1:3:2:3=>-0.123304*0.1    ;  1:3:2:4=>-0.113662*0.001  ;
 1:3:3:1=> 0.939720*100    ;  1:3:3:2=> 0.874997        ;  1:3:3:3=>-0.174451*0.1    ;  1:3:3:4=> 0.693745*0.001  ;
 2:1:1:1=> 0.457829*100    ;  2:1:1:2=> 0.367323*10     ;  2:1:1:3=>-0.237212        ;  2:1:1:4=> 0.779334*0.01   ;
 2:1:2:1=> 0.653091*100    ;  2:1:2:2=> 0.129719*10     ;  2:1:2:3=>-0.267922*0.1    ;  2:1:2:4=> 0.466010*0.001  ;
 2:1:3:1=> 0.803115*100    ;  2:1:3:2=> 0.807980        ;  2:1:3:3=>-0.582173*0.01   ;  2:1:3:4=>-0.184636*0.001  ;
 2:2:1:1=> 0.498644*100    ;  2:2:1:2=> 0.393746*10     ;  2:2:1:3=>-0.262999        ;  2:2:1:4=> 0.884779*0.01   ;
 2:2:2:1=> 0.704487*100    ;  2:2:2:2=> 0.135350*10     ;  2:2:2:3=>-0.241086*0.1    ;  2:2:2:4=> 0.339627*0.001  ;
 2:2:3:1=> 0.864730*100    ;  2:2:3:2=> 0.859488        ;  2:2:3:3=>-0.882537*0.01   ;  2:2:3:4=> 0.322490*0.0001 ;
 2:3:1:1=> 0.539292*100    ;  2:3:1:2=> 0.421102*10     ;  2:3:1:3=>-0.290055        ;  2:3:1:4=> 0.995372*0.01   ;
 2:3:2:1=> 0.755903*100    ;  2:3:2:2=> 0.140880*10     ;  2:3:2:3=>-0.213041*0.1    ;  2:3:2:4=> 0.210055*0.001  ;
 2:3:3:1=> 0.926378*100    ;  2:3:3:2=> 0.911461        ;  2:3:3:3=>-0.118516*0.1    ;  2:3:3:4=> 0.242960*0.001  ;
 3:1:1:1=> 0.249740*10     ;  3:1:1:2=> 0.462056        ;  3:1:1:3=> 0.481125*0.1    ;  3:1:1:4=>-0.458894*0.01   ;
 3:1:2:1=> 0.601058*10     ;  3:1:2:2=> 0.543800        ;  3:1:2:3=>-0.344885*0.1    ;  3:1:2:4=> 0.973626*0.001  ;
 3:1:3:1=> 0.925227*10     ;  3:1:3:2=> 0.136684        ;  3:1:3:3=> 0.562077*0.001  ;  3:1:3:4=>-0.236327*0.0001 ;
 3:2:1:1=> 0.326804*10     ;  3:2:1:2=> 0.108795*10     ;  3:2:1:3=>-0.677657*0.1    ;  3:2:1:4=> 0.226565*0.01   ;
 3:2:2:1=> 0.784554*10     ;  3:2:2:2=> 0.519450        ;  3:2:2:3=>-0.269840*0.1    ;  3:2:2:4=> 0.738014*0.001  ;
 3:2:3:1=> 0.114685*100    ;  3:2:3:2=> 0.190655        ;  3:2:3:3=>-0.415541*0.001  ;  3:2:3:4=>-0.133747*0.0001 ;
 3:3:1:1=> 0.420915*10     ;  3:3:1:2=> 0.145910*10     ;  3:3:1:3=>-0.124212        ;  3:3:1:4=> 0.546698*0.01   ;
 3:3:2:1=> 0.967299*10     ;  3:3:2:2=> 0.558989        ;  3:3:2:3=>-0.258067*0.1    ;  3:3:2:4=> 0.644479*0.001  ;
 3:3:3:1=> 0.137784*100    ;  3:3:3:2=> 0.218043        ;  3:3:3:3=>-0.260545*0.01   ;  3:3:3:4=> 0.106811*0.001  ;
 4:1:1:1=> 0.230235*10     ;  4:1:1:2=> 0.545715        ;  4:1:1:3=> 0.131161*0.1    ;  4:1:1:4=>-0.221402*0.01   ;
 4:1:2:1=> 0.557059*10     ;  4:1:2:2=> 0.463994        ;  4:1:2:3=>-0.267363*0.1    ;  4:1:2:4=> 0.773006*0.001  ;
 4:1:3:1=> 0.862425*10     ;  4:1:3:2=> 0.156261        ;  4:1:3:3=> 0.109190*0.01   ;  4:1:3:4=>-0.898380*0.0001 ;
 4:2:1:1=> 0.322751*10     ;  4:2:1:2=> 0.768817        ;  4:2:1:3=>-0.124130*0.1    ;  4:2:1:4=>-0.857452*0.001  ;
 4:2:2:1=> 0.720834*10     ;  4:2:2:2=> 0.527256        ;  4:2:2:3=>-0.278471*0.1    ;  4:2:2:4=> 0.752199*0.001  ;
 4:2:3:1=> 0.108252*100    ;  4:2:3:2=> 0.183875        ;  4:2:3:3=>-0.767982*0.001  ;  4:2:3:4=> 0.714597*0.00001;
 4:3:1:1=> 0.391945*10     ;  4:3:1:2=> 0.115426*10     ;  4:3:1:3=>-0.635733*0.1    ;  4:3:1:4=> 0.176581*0.01   ;
 4:3:2:1=> 0.893781*10     ;  4:3:2:2=> 0.582092        ;  4:3:2:3=>-0.317886*0.1    ;  4:3:2:4=> 0.930288*0.001  ;
 4:3:3:1=> 0.129529*100    ;  4:3:3:2=> 0.221049        ;  4:3:3:3=> 0.170173*0.01   ;  4:3:3:4=>-0.906913*0.0001 ;
 5:1:1:1=> 0.250836*10     ;  5:1:1:2=> 0.681768*0.1    ;  5:1:1:3=> 0.126871*0.1    ;  5:1:1:4=>-0.259413*0.001  ;
 5:1:2:1=> 0.763160*10     ;  5:1:2:2=> 0.240094        ;  5:1:2:3=>-0.521241*0.01   ;  5:1:2:4=> 0.150006*0.001  ;
 5:1:3:1=> 0.111393*100    ;  5:1:3:2=> 0.198252        ;  5:1:3:3=> 0.288790*0.01   ;  5:1:3:4=>-0.207356*0.0001 ;
 5:2:1:1=> 0.314986*10     ;  5:2:1:2=> 0.148592        ;  5:2:1:3=> 0.947678*0.01   ;  5:2:1:4=>-0.205609*0.001  ;
 5:2:2:1=> 0.907905*10     ;  5:2:2:2=> 0.258223        ;  5:2:2:3=>-0.471024*0.01   ;  5:2:2:4=> 0.132953*0.001  ;
 5:2:3:1=> 0.129763*100    ;  5:2:3:2=> 0.217885        ;  5:2:3:3=> 0.246924*0.01   ;  5:2:3:4=> 0.104389*0.001  ;
 5:3:1:1=> 0.409354*10     ;  5:3:1:2=> 0.188963        ;  5:3:1:3=> 0.873912*0.01   ;  5:3:1:4=>-0.193446*0.001  ;
 5:3:2:1=> 0.107090*100    ;  5:3:2:2=> 0.283963        ;  5:3:2:3=>-0.460866*0.01   ;  5:3:2:4=> 0.113211*0.001  ;
 5:3:3:1=> 0.149874*100    ;  5:3:3:2=> 0.228093        ;  5:3:3:3=> 0.150476*0.01   ;  5:3:3:4=> 0.133490*0.001  ;
 6:1:1:1=> 0.260988*10     ;  6:1:1:2=> 0.630037*0.1    ;  6:1:1:3=> 0.115431*0.1    ;  6:1:1:4=>-0.231559*0.001  ;
 6:1:2:1=> 0.734790*10     ;  6:1:2:2=> 0.226503        ;  6:1:2:3=>-0.443447*0.01   ;  6:1:2:4=> 0.137357*0.001  ;
 6:1:3:1=> 0.107892*100    ;  6:1:3:2=> 0.200373        ;  6:1:3:3=> 0.298280*0.01   ;  6:1:3:4=> 0.891100*0.0001 ;
 6:2:1:1=> 0.329545*10     ;  6:2:1:2=> 0.103651        ;  6:2:1:3=> 0.119637*0.1    ;  6:2:1:4=>-0.255793*0.001  ;
 6:2:2:1=> 0.889598*10     ;  6:2:2:2=> 0.248036        ;  6:2:2:3=>-0.568606*0.01   ;  6:2:2:4=> 0.181276*0.001  ;
 6:2:3:1=> 0.125756*100    ;  6:2:3:2=> 0.219539        ;  6:2:3:3=> 0.410286*0.01   ;  6:2:3:4=>-0.204386*0.0001 ;
 6:3:1:1=> 0.393902*10     ;  6:3:1:2=> 0.201926        ;  6:3:1:3=> 0.746380*0.01   ;  6:3:1:4=>-0.178154*0.001  ;
 6:3:2:1=> 0.103641*100    ;  6:3:2:2=> 0.262530        ;  6:3:2:3=>-0.482882*0.01   ;  6:3:2:4=> 0.154783*0.001  ;
 6:3:3:1=> 0.144278*100    ;  6:3:3:2=> 0.239142        ;  6:3:3:3=> 0.352948*0.01   ;  6:3:3:4=> 0.139341*0.001  ;
 7:1:1:1=> 0.322108*100    ;  7:1:1:2=> 0.258812*10     ;  7:1:1:3=>-0.249611        ;  7:1:1:4=> 0.111355*0.1    ;
 7:1:2:1=> 0.411588*100    ;  7:1:2:2=> 0.795414        ;  7:1:2:3=>-0.491726*0.1    ;  7:1:2:4=> 0.131269*0.01   ;
 7:1:3:1=> 0.458912*100    ;  7:1:3:2=> 0.182354        ;  7:1:3:3=>-0.191581*0.01   ;  7:1:3:4=>-0.463902*0.0001 ;
 7:2:1:1=> 0.348510*100    ;  7:2:1:2=> 0.253355*10     ;  7:2:1:3=>-0.235109        ;  7:2:1:4=> 0.101480*0.1    ;
 7:2:2:1=> 0.437804*100    ;  7:2:2:2=> 0.808235        ;  7:2:2:3=>-0.524443*0.1    ;  7:2:2:4=> 0.140200*0.01   ;
 7:2:3:1=> 0.483499*100    ;  7:2:3:2=> 0.155234        ;  7:2:3:3=>-0.197246*0.01   ;  7:2:3:4=>-0.549570*0.00001;
 7:3:1:1=> 0.373458*100    ;  7:3:1:2=> 0.284554*10     ;  7:3:1:3=>-0.312001        ;  7:3:1:4=> 0.150148*0.1    ;
 7:3:2:1=> 0.464302*100    ;  7:3:2:2=> 0.723126        ;  7:3:2:3=>-0.417343*0.1    ;  7:3:2:4=> 0.106348*0.01   ;
 7:3:3:1=> 0.509357*100    ;  7:3:3:2=> 0.180925        ;  7:3:3:3=>-0.344910*0.01   ;  7:3:3:4=> 0.218012*0.0001 ;
 8:1:1:1=> 0.320688*100    ;  8:1:1:2=> 0.210232*10     ;  8:1:1:3=>-0.165974        ;  8:1:1:4=> 0.640051*0.01   ;
 8:1:2:1=> 0.400902*100    ;  8:1:2:2=> 0.801885        ;  8:1:2:3=>-0.507646*0.1    ;  8:1:2:4=> 0.138010*0.01   ;
 8:1:3:1=> 0.447875*100    ;  8:1:3:2=> 0.179737        ;  8:1:3:3=>-0.108106*0.01   ;  8:1:3:4=>-0.652464*0.0001 ;
 8:2:1:1=> 0.342817*100    ;  8:2:1:2=> 0.231444*10     ;  8:2:1:3=>-0.217205        ;  8:2:1:4=> 0.966608*0.01   ;
 8:2:2:1=> 0.424368*100    ;  8:2:2:2=> 0.751914        ;  8:2:2:3=>-0.432157*0.1    ;  8:2:2:4=> 0.108307*0.01   ;
 8:2:3:1=> 0.471083*100    ;  8:2:3:2=> 0.182624        ;  8:2:3:3=>-0.422515*0.01   ;  8:2:3:4=> 0.400879*0.0001 ;
 8:3:1:1=> 0.359806*100    ;  8:3:1:2=> 0.283176*10     ;  8:3:1:3=>-0.317336        ;  8:3:1:4=> 0.154859*0.1    ;
 8:3:2:1=> 0.448920*100    ;  8:3:2:2=> 0.696214        ;  8:3:2:3=>-0.385893*0.1    ;  8:3:2:4=> 0.942081*0.001  ;
 8:3:3:1=> 0.493177*100    ;  8:3:3:2=> 0.177050        ;  8:3:3:3=>-0.467440*0.01   ;  8:3:3:4=> 0.903841*0.0001 ;
 9:1:1:1=> 0.796017*100    ;  9:1:1:2=> 0.725005        ;  9:1:1:3=>-0.394565*0.01   ;  9:1:1:4=> 0.149043*0.0001 ;
 9:1:2:1=> 0.133056*1000   ;  9:1:2:2=> 0.406485        ;  9:1:2:3=> 0.115162*0.01   ;  9:1:2:4=> 0.272229*0.0001 ;
 9:1:3:1=> 0.147022*1000   ;  9:1:3:2=> 0.549084        ;  9:1:3:3=> 0.360168*0.01   ;  9:1:3:4=>-0.162614*0.001  ;
 9:1:4:1=> 0.163870*1000   ;  9:1:4:2=> 0.176161        ;  9:1:4:3=>-0.139606*0.1    ;  9:1:4:4=> 0.257402*0.001  ;
 9:2:1:1=> 0.855931*100    ;  9:2:1:2=> 0.837795        ;  9:2:1:3=>-0.533792*0.01   ;  9:2:1:4=> 0.233837*0.0001 ;
 9:2:2:1=> 0.146374*1000   ;  9:2:2:2=> 0.532432        ;  9:2:2:3=> 0.265930*0.01   ;  9:2:2:4=>-0.599481*0.0001 ;
 9:2:3:1=> 0.163122*1000   ;  9:2:3:2=> 0.530131        ;  9:2:3:3=>-0.273603*0.01   ;  9:2:3:4=>-0.522667*0.0001 ;
 9:2:4:1=> 0.176222*1000   ;  9:2:4:2=> 0.129924        ;  9:2:4:3=>-0.838083*0.01   ;  9:2:4:4=> 0.143430*0.001  ;
 9:3:1:1=> 0.915767*100    ;  9:3:1:2=> 0.950895        ;  9:3:1:3=>-0.673349*0.01   ;  9:3:1:4=> 0.318732*0.0001 ;
 9:3:2:1=> 0.159692*1000   ;  9:3:2:2=> 0.658332        ;  9:3:2:3=> 0.416714*0.01   ;  9:3:2:4=>-0.147054*0.001  ;
 9:3:3:1=> 0.179222*1000   ;  9:3:3:2=> 0.511316        ;  9:3:3:3=>-0.906767*0.01   ;  9:3:3:4=> 0.577848*0.0001 ;
 9:3:4:1=> 0.188574*1000   ;  9:3:4:2=> 0.831110*0.1    ;  9:3:4:3=>-0.282691*0.01   ;  9:3:4:4=> 0.382714*0.0001 ;
10:1:1:1=> 0.784609*100    ; 10:1:1:2=> 0.769969        ; 10:1:1:3=>-0.579066*0.01   ; 10:1:1:4=> 0.299200*0.0001 ;
10:1:2:1=> 0.100071*1000   ; 10:1:2:2=> 0.469370        ; 10:1:2:3=>-0.255930*0.01   ; 10:1:2:4=> 0.298134*0.0001 ;
10:1:3:1=> 0.131726*1000   ; 10:1:3:2=> 0.564490        ; 10:1:3:3=> 0.388040*0.01   ; 10:1:3:4=>-0.211730*0.001  ;
10:1:4:1=> 0.144582*1000   ; 10:1:4:2=> 0.384879        ; 10:1:4:3=>-0.113642*0.1    ; 10:1:4:4=> 0.132304*0.001  ;
10:1:5:1=> 0.149882*1000   ; 10:1:5:2=> 0.810578*0.1    ; 10:1:5:3=> 0.292469*0.01   ; 10:1:5:4=>-0.738429*0.0001 ;
10:2:1:1=> 0.844872*100    ; 10:2:1:2=> 0.877385        ; 10:2:1:3=>-0.854191*0.01   ; 10:2:1:4=> 0.726632*0.0001 ;
10:2:2:1=> 0.105083*1000   ; 10:2:2:2=> 0.561061        ; 10:2:2:3=>-0.200222*0.01   ; 10:2:2:4=> 0.171075*0.0001 ;
10:2:3:1=> 0.144783*1000   ; 10:2:3:2=> 0.560961        ; 10:2:3:3=> 0.200094*0.01   ; 10:2:3:4=>-0.164240*0.001  ;
10:2:4:1=> 0.157128*1000   ; 10:2:4:2=> 0.373200        ; 10:2:4:3=>-0.982432*0.01   ; 10:2:4:4=> 0.982153*0.0001 ;
10:2:5:1=> 0.162413*1000   ; 10:2:5:2=> 0.477105*0.1    ; 10:2:5:3=> 0.782933*0.001  ; 10:2:5:4=>-0.217935*0.0001 ;
10:3:1:1=> 0.905784*100    ; 10:3:1:2=> 0.973526        ; 10:3:1:3=>-0.108372*0.1    ; 10:3:1:4=> 0.109954*0.001  ;
10:3:2:1=> 0.112999*1000   ; 10:3:2:2=> 0.620169        ; 10:3:2:3=>-0.941330*0.001  ; 10:3:2:4=> 0.461746*0.00001;
10:3:3:1=> 0.157837*1000   ; 10:3:3:2=> 0.557600        ; 10:3:3:3=> 0.139156*0.001  ; 10:3:3:4=>-0.117406*0.001  ;
10:3:4:1=> 0.169676*1000   ; 10:3:4:2=> 0.361401        ; 10:3:4:3=>-0.831408*0.01   ; 10:3:4:4=> 0.648912*0.0001 ;
10:3:5:1=> 0.174939*1000   ; 10:3:5:2=> 0.150850*0.1    ; 10:3:5:3=>-0.130583*0.01   ; 10:3:5:4=> 0.268575*0.0001 ;
11:1:1:1=> 0.102271*100    ; 11:1:1:2=> 0.110605        ; 11:1:1:3=> 0.502728*0.001  ; 11:1:1:4=>-0.356088*0.00001;
11:1:2:1=> 0.194677*100    ; 11:1:2:2=> 0.127619        ; 11:1:2:3=>-0.266421*0.001  ; 11:1:2:4=> 0.234381*0.0001 ;
11:1:3:1=> 0.312284*100    ; 11:1:3:2=> 0.348780        ; 11:1:3:3=> 0.395244*0.01   ; 11:1:3:4=>-0.674519*0.0001 ;
11:1:4:1=> 0.496166*100    ; 11:1:4:2=> 0.261986        ; 11:1:4:3=>-0.576064*0.01   ; 11:1:4:4=> 0.333672*0.0001 ;
11:2:1:1=> 0.123424*100    ; 11:2:1:2=> 0.202445        ; 11:2:1:3=>-0.116412*0.01   ; 11:2:1:4=> 0.118225*0.0001 ;
11:2:2:1=> 0.252964*100    ; 11:2:2:2=> 0.218676        ; 11:2:2:3=> 0.138954*0.01   ; 11:2:2:4=> 0.709375*0.00001;
11:2:3:1=> 0.449515*100    ; 11:2:3:2=> 0.462032        ; 11:2:3:3=> 0.266641*0.01   ; 11:2:3:4=>-0.629917*0.0001 ;
11:2:4:1=> 0.663061*100    ; 11:2:4:2=> 0.282610        ; 11:2:4:3=>-0.640439*0.01   ; 11:2:4:4=> 0.619515*0.0001 ;
11:3:1:1=> 0.154874*100    ; 11:3:1:2=> 0.219986        ; 11:3:1:3=>-0.841307*0.001  ; 11:3:1:4=> 0.189821*0.0001 ;
11:3:2:1=> 0.340501*100    ; 11:3:2:2=> 0.394048        ; 11:3:2:3=> 0.325883*0.01   ; 11:3:2:4=>-0.164077*0.0001 ;
11:3:3:1=> 0.658807*100    ; 11:3:3:2=> 0.607904        ; 11:3:3:3=> 0.305441*0.001  ; 11:3:3:4=>-0.377818*0.0001 ;
11:3:4:1=> 0.915854*100    ; 11:3:4:2=> 0.376078        ; 11:3:4:3=>-0.513514*0.01   ; 11:3:4:4=>-0.177567*0.0001 ;
12:1:1:1=> 0.958878*10     ; 12:1:1:2=> 0.162168        ; 12:1:1:3=>-0.158785*0.01   ; 12:1:1:4=> 0.141728*0.0001 ;
12:1:2:1=> 0.166639*100    ; 12:1:2:2=> 0.124691        ; 12:1:2:3=> 0.963245*0.001  ; 12:1:2:4=> 0.307446*0.00001;
12:1:3:1=> 0.282771*100    ; 12:1:3:2=> 0.273485        ; 12:1:3:3=> 0.151665*0.01   ; 12:1:3:4=>-0.370240*0.0001 ;
12:1:4:1=> 0.408042*100    ; 12:1:4:2=> 0.163173        ; 12:1:4:3=>-0.381481*0.01   ; 12:1:4:4=> 0.315956*0.0001 ;
12:2:1:1=> 0.117963*100    ; 12:2:1:2=> 0.219662        ; 12:2:1:3=>-0.262788*0.01   ; 12:2:1:4=> 0.292835*0.0001 ;
12:2:2:1=> 0.218409*100    ; 12:2:2:2=> 0.220578        ; 12:2:2:3=> 0.264314*0.01   ; 12:2:2:4=>-0.141618*0.0001 ;
12:2:3:1=> 0.415319*100    ; 12:2:3:2=> 0.384808        ; 12:2:3:3=> 0.940228*0.0001 ; 12:2:3:4=>-0.391686*0.0001 ;
12:2:4:1=> 0.558876*100    ; 12:2:4:2=> 0.123101        ; 12:2:4:3=>-0.554625*0.01   ; 12:2:4:4=> 0.702252*0.0001 ;
12:3:1:1=> 0.144385*100    ; 12:3:1:2=> 0.322835        ; 12:3:1:3=>-0.438366*0.01   ; 12:3:1:4=> 0.540144*0.0001 ;
12:3:2:1=> 0.296945*100    ; 12:3:2:2=> 0.380152        ; 12:3:2:3=> 0.533894*0.01   ; 12:3:2:4=>-0.449181*0.0001 ;
12:3:3:1=> 0.620215*100    ; 12:3:3:2=> 0.535709        ; 12:3:3:3=>-0.274632*0.01   ; 12:3:3:4=>-0.206170*0.0001 ;
12:3:4:1=> 0.791280*100    ; 12:3:4:2=> 0.129558        ; 12:3:4:3=>-0.571516*0.01   ; 12:3:4:4=> 0.648512*0.0001 ;
13:1:1:1=> 0.288221*10     ; 13:1:1:2=> 0.311757        ; 13:1:1:3=>-0.339993*0.01   ; 13:1:1:4=> 0.332712*0.0001 ;
13:1:2:1=> 0.907104*10     ; 13:1:2:2=> 0.204144        ; 13:1:2:3=>-0.904587*0.001  ; 13:1:2:4=> 0.465496*0.0001 ;
13:1:3:1=> 0.171038*100    ; 13:1:3:2=> 0.311893        ; 13:1:3:3=> 0.398312*0.01   ; 13:1:3:4=>-0.276662*0.0001 ;
13:2:1:1=> 0.431260*10     ; 13:2:1:2=> 0.371447        ; 13:2:1:3=>-0.633119*0.01   ; 13:2:1:4=> 0.877037*0.0001 ;
13:2:2:1=> 0.110122*100    ; 13:2:2:2=> 0.219333        ; 13:2:2:3=> 0.246595*0.001  ; 13:2:2:4=> 0.313171*0.0001 ;
13:2:3:1=> 0.203336*100    ; 13:2:3:2=> 0.351685        ; 13:2:3:3=> 0.353489*0.01   ; 13:2:3:4=> 0.104383*0.001  ;
13:3:1:1=> 0.658687*10     ; 13:3:1:2=> 0.352637        ; 13:3:1:3=>-0.345830*0.01   ; 13:3:1:4=> 0.293354*0.0001 ;
13:3:2:1=> 0.136997*100    ; 13:3:2:2=> 0.234726        ; 13:3:2:3=>-0.125814*0.01   ; 13:3:2:4=> 0.889698*0.0001 ;
13:3:3:1=> 0.241885*100    ; 13:3:3:2=> 0.473620        ; 13:3:3:3=> 0.808368*0.01   ; 13:3:3:4=> 0.103298*0.001  ;
14:1:1:1=> 0.303896*10     ; 14:1:1:2=> 0.276098        ; 14:1:1:3=>-0.226928*0.01   ; 14:1:1:4=> 0.201277*0.0001 ;
14:1:2:1=> 0.982301*10     ; 14:1:2:2=> 0.194286        ; 14:1:2:3=>-0.457785*0.001  ; 14:1:2:4=> 0.537775*0.0001 ;
14:1:3:1=> 0.147037*100    ; 14:1:3:2=> 0.258573        ; 14:1:3:3=> 0.325286*0.01   ; 14:1:3:4=> 0.168530*0.0001 ;
14:2:1:1=> 0.430208*10     ; 14:2:1:2=> 0.364667        ; 14:2:1:3=>-0.629446*0.01   ; 14:2:1:4=> 0.835936*0.0001 ;
14:2:2:1=> 0.118341*100    ; 14:2:2:2=> 0.212702        ; 14:2:2:3=> 0.122896*0.01   ; 14:2:2:4=> 0.201561*0.0001 ;
14:2:3:1=> 0.176216*100    ; 14:2:3:2=> 0.301222        ; 14:2:3:3=> 0.261973*0.01   ; 14:2:3:4=> 0.121334*0.001  ;
14:3:1:1=> 0.658206*10     ; 14:3:1:2=> 0.363970        ; 14:3:1:3=>-0.609859*0.01   ; 14:3:1:4=> 0.885250*0.0001 ;
14:3:2:1=> 0.144026*100    ; 14:3:2:2=> 0.237072        ; 14:3:2:3=> 0.186866*0.01   ; 14:3:2:4=> 0.269321*0.0001 ;
14:3:3:1=> 0.211715*100    ; 14:3:3:2=> 0.365772        ; 14:3:3:3=> 0.372698*0.01   ; 14:3:3:4=> 0.332188*0.001  ;
  endrecode;
  zscoef = zscoeff;
end;

{ --------------------------------------------------------------------------- }
{ dabs
  Returns: the absolute value of input variable                               }

function dabs(dval);
  if dval < 0 then dval = - dval endif;
  dabs = dval;
end;

{ --------------------------------------------------------------------------- }
{ Anthropometry function }
function zspct(zssd);
  if zssd > 9.985 then
    zspct = 99.9
  else
    zsr  =  0.2316419;
    zsb1 =  0.31938153;
    zsb2 = -0.356563782;
    zsb3 =  1.781477937;
    zsb4 = -1.821255978;
    zsb5 =  1.330274429;
    zsdz = dabs(zssd);
    zst = 1/(1+zsdz*zsr);
    zsdzp = zsb1*zst+zsb2*zst^2+zsb3*zst^3+zsb4*zst^4+zsb5*zst^5;
    zsfx = 1/sqrt(8*0.785398163)*exp(-0.5*zsdz^2);
                   { ATAN(1.0) }
    zsdzp = zsdzp*zsfx*100;
    if zssd >= 0 then zsdzp= 100 - zsdzp endif;
    if zsdzp > 99.8 then zsdzp = 99.8 endif;
    zspct = zsdzp;
  endif;
end;

{ --------------------------------------------------------------------------- }
{ Anthropometry function }
function zseval(zsx,zsy);
  if (zsx < zsll or zsx > zsul) and zsll <> zsul then
    zseval = 999.9
  else
    recode zsi => zsk;
       9,11,12 => 4;
            10 => 5;
               => 3;
    endrecode;
    zsj = zsy;
    zsa = -1;
    while zsk > 0 and zsa < 0 do
      recode zsi : zsk => zsknot;
            1 : 1 =>  0;  1 : 2 =>  9;  1 : 3 => 24;
            2 : 1 =>  0;  2 : 2 =>  9;  2 : 3 => 24;
            3 : 1 =>  0;  3 : 2 =>  6;  3 : 3 => 18;
            4 : 1 =>  0;  4 : 2 =>  6;  4 : 3 => 18;
            5 : 1 => 49;  5 : 2 => 72;  5 : 3 => 90;
            6 : 1 => 49;  6 : 2 => 72;  6 : 3 => 90;
         {  7 : 1 =>  0;  7 : 2 =>  6;  7 : 3 => 18;
            8 : 1 =>  0;  8 : 2 =>  6;  8 : 3 => 18; }
            9 : 1 => 24;  9 : 2 =>138;  9 : 3 =>168;  9 : 4 =>204;
           10 : 1 => 24; 10 : 2 => 54; 10 : 3 =>132; 10 : 4 =>156; 10 : 5 =>192;
           11 : 1 => 24; 11 : 2 => 96; 11 : 3 =>156; 11 : 4 =>204;
           12 : 1 => 24; 12 : 2 => 84; 12 : 3 =>144; 12 : 4 =>192;
           13 : 1 => 55; 13 : 2 => 80; 13 : 3 =>115;
           14 : 1 => 55; 14 : 2 => 85; 14 : 3 =>108;
              :   => default;
      endrecode;
      if zsi = 10 and zsj = 1 and zsk = 2 then zsknot = 60 endif;
      zsa = zsx-zsknot;
      if zsa < 0 then zsk = zsk-1 endif;
    enddo;
    if zsk = 0 then zsk = 1 endif;
    zsl = 4;
    zsz = 0;
    while zsl > 0 do
      zsz = zsz*zsa+zscoef(zsi,zsj,zsk,zsl);
      zsl = zsl-1;
    enddo;
    zseval=zsz;
  endif;
end;

{ --------------------------------------------------------------------------- }
{ Anthropometry function }
function zscr(zsx,zsms);
  if ((zsx < zsll or zsx > zsul) and zsll <> zsul) then
    zsc=9.99
  else
    zsy1=zseval(zsx,1);
    zsy2=zseval(zsx,2);
    zsy3=zseval(zsx,3);
    zssd1=(zsy2-zsy1)/1.8807936; if zssd1 < 0 then zssd1 = -zssd1 endif;
    zssd2=(zsy2-zsy3)/1.8807936; if zssd2 < 0 then zssd2 = -zssd2 endif;
    if zsll = zsul then
      zsc=zsy2;
      zsll=zssd1;
      zsul=zssd2;
    else
      if zsms < zsy2 then
        zsc=(zsms-zsy2)/zssd1;
        if zsc < -9.98 then zsc=-9.98 endif;
      else
        zsc=(zsms-zsy2)/zssd2;
        if zsc > 9.98 then zsc=9.98 endif;
      endif;
    endif;
  endif;
  zscr = zsc;
end;

{ --------------------------------------------------------------------------- }
{ Anthropometry function }
function zsanth(zsage,zssex,zswt,zsht,zsageok)
  if zssex = 1 or zssex = 2 then
    if (zsageok = 1 and zsage >= 24) or (zsageok <> 1 and zsht >= 85) then
      { FELS REFERENCE THROUGH 36 MONTHS      }
      { CHANGE TO >= 24 FOR REGULAR REFERENCE }
      zsi=zssex+8
    else
      zsi=zssex
    endif;
    if zsageok = 1 then
      { Ht/Age }
      if zsage < 24 then
        zshta = zsht;
        zsll=0; zsul=36;
      else
        zshta = zsht {- 1} ;    { Subtract 1 if lying after 24 months !!! }
        zsll=24; zsul=216;
      endif;
      if zsage < zsll or zsage > zsul or
         zshta > 999 or zshta <= 0.01 then
        zspmed=999.9;
        zsc=9.99;
      else
        zsv = zseval(zsage,2);
        zsc = zscr(zsage,zshta);
        zspmed = (zshta/zsv)*100;
      endif;
      zshap=zspmed;
      zshaz=zsc;
      zshac=zspct(zsc);
    endif;
    { Wt/Age }
    zsi = zsi + 2;
    if zsageok = 1 then
      if zsage < 24 then
        zsll=0; zsul=36;
      else
        zsll=24; zsul=216;
      endif;
      if zsage < zsll or zsage > zsul or
         zswt > 999 or zswt <= 0.01 then
        zspmed=999.9;
        zsc=9.99;
      else
        zsv = zseval(zsage,2);
        zsc = zscr(zsage,zswt);
        zspmed = (zswt/zsv)*100;
      endif;
      zswap=zspmed;
      zswaz=zsc;
      zswac=zspct(zsc);
    endif;
    { Wt/Ht }
    zsi = zsi + 2;
    if (zsageok = 1 and zsage < 24) or (zsageok <> 1 and zshtw < 85) then
      zshtw = zsht;
      zsll=49; if zssex = 1 then zsul=103 else zsul=101 endif;
    else
      zshtw = zsht {- 1} ;      { Subtract 1 if lying after 24 months !!! }
      zsll=55; if zssex = 1 then zsul=145 else zsul=137 endif;
    endif;
    if zshtw < zsll or zshtw > zsul or
       zswt > 999 or zswt <= 0.01 then
      zspmed=999.9;
      zsc=9.99;
    else
      zsv = zseval(zshtw,2);
      zsc = zscr(zshtw,zswt);
      zspmed = (zswt/zsv)*100;
    endif;
    zswhp=zspmed;
    zswhz=zsc;
    zswhc=zspct(zsc);
    if zsageok = 1 then
      if zsage < 24 then
        zsll=0; zsul=36;
      else
        zsll=24; if zssex = 1 then zsul=138 else zsul=120 endif;
      endif;
      if zsage < zsll or zsage > zsul then
        zswhc=99.9;
        zswhp=999.9;
        zswhz=9.99;
      endif;
    endif;
    zsanth = 1;
  else
    zshac=99.9;
    zshap=999.9;
    zshaz=9.99;
    zswac=99.9;
    zswap=999.9;
    zswaz=9.99;
    zswhc=99.9;
    zswhp=999.9;
    zswhz=9.99;
    zsanth = 0;
  endif;
  fhaz = 0; fwaz = 0; fwhz = 0;
  if zshaz <= -6.00 or zshaz >= 6.00 then      { h/a out of range }
    fhaz = 1;
  endif;
  if zswaz <= -6.00 or zswaz >= 6.00 then      { w/a out of range }
    fwaz = 1;
  endif;
  if zswhz <= -4.00 or zswhz >= 6.00 then      { w/h out of range }
    fwhz = 1;
  endif;
  if zshaz <  -3.09 and  zswhz >  3.09 then      { height too low  }
    fhaz = 1; fwhz = 1;
  endif;
  if zshaz >   3.09 and  zswhz < -3.09 then      { height too high }
    fhaz = 1; fwhz = 1;
  endif;
  zsflag = 4*fwaz+2*fwhz+fhaz;
end;

{ --------------------------------------------------------------------------- }
{ agemth
  Calculates most accurate age in months possible (used for anthropometry)
  Input: Birth day, month, year and interview day, month, year
  Returns:
	- Childs age in months if birth day, month and year are valid
	- Childs age in months using 15 as day if only birth month and year are valid
	- special if only birth year is valid                                        }

  function agemth(xhwbd,xhwbm,xhwby,xhwmd,xhwmm,xhwmy);
    { if birth month and year and measurement day, month and year are all valid }
        if valid(xhwbm) and xhwby < 9996 and valid(xhwmd) and valid(xhwmm) and xhwmy < 9996 then
      { if day of birth inconsistent, don't know or missing }
      if not(valid(xhwbd)) then
        { impute day of birth }
        xhwbd = 15;
      endif;
      leapday = (xhwby % 4 = 0);
      xdays1 = xhwbd;
      do x = 1 while x < xhwbm
        recode x        => y;
           1,3,5,7,8,10 => 31;
                      2 => 28+leapday;
               4,6,9,11 => 30;
        endrecode;
        xdays1 = xdays1 + y;
      enddo;
      leapday = (xhwmy % 4 = 0);
      xdays2 = xhwmd;
      do x = 1 while x < xhwmm
        recode x        => y;
           1,3,5,7,8,10 => 31;
                      2 => 28+leapday;
               4,6,9,11 => 30;
        endrecode;
        xdays2 = xdays2 + y;
      enddo;
      do x = xhwby while x < xhwmy
        xdays2 = xdays2 + 365 + (x % 4 = 0);
      enddo;
      agemth = int(((xdays2 - xdays1)/30.4375)*100+0.5)/100;
    else
      agemth = 9999;
    endif;
  end;

{ --------------------------------------------------------------------------- }
{ vdvalid
  Checks that date is valid. Used for checking vaccination dates.
  Missing, dont know etc are considered valid
  Returns: 0 if valid, otherwise 1				  							  }

function vdvalid(vcheckd,vcheckm,vchecky);
  vdvalid = 0;
  { Check day, month and year are consistent }
  recode    vchecky   : vcheckm               : vcheckd    => vcheckx; { !!! }
   				 9999 : 99                    : 99         => 1;
  2004-2012,9996-9999 : 1,3,5,7,8,10,12,96-99 : 1-31,96-99 => 0;
  2004-2012,9996-9999 : 4,6,9,11              : 1-30,96-99 => 0;
  2004-2012,9996-9999 : 2                     : 1-28,96-99 => 0;    
      2004,2008, 2012 : 2                     : 29         => 0;      { leap year }
              notappl : notappl               : 66         => 0;
              notappl : notappl               : 44         => 0;
              notappl : notappl               : 0          => 0;
                      :                       :            => 1;
  endrecode;
  if vcheckx then
    vdvalid = 1;
  endif;
end;

{ --------------------------------------------------------------------------- }
{ vdoi
  Check vaccination date is before date of interview.
  Returns: 0 if vaccination date is before interview, otherwise 1 }
function vdoi(vcheckd,vcheckm,vchecky);
  vdoi = 0;
  if (vcheckd < 44 and vcheckd > 0) and valid(vcheckm) and vchecky < 9996 then
    if (cmcode(vcheckm,vchecky) > cmcode(UF8M,UF8Y)) |
       (cmcode(vcheckm,vchecky) = cmcode(UF8M,UF8Y) and vcheckd > UF8D) then
      vdoi = 1;
    endif;
  elseif valid(vcheckm) and vchecky < 9996 then
    if (cmcode(vcheckm,vchecky) > cmcode(UF8M,UF8Y)) then
      vdoi = 1;
    endif;
  elseif vchecky < 9996 then
    if vchecky > UF8Y then
      vdoi = 1;
    endif;
  endif;
end;

{ --------------------------------------------------------------------------- }
{ vdob
  Check vaccination date is after date of birth
  Returns: 0 if vaccination date is after birth, otherwise 1  }
function vdob(vcheckd,vcheckm,vchecky);
  vdob = 0;
  if valid(AG1D) and valid(AG1M) and AG1Y < 9996 then
    if vcheckd < 44 and valid(vcheckm) and vchecky < 9996 then
      if cmcode(vcheckm,vchecky) < cmcode(AG1M,AG1Y) | (cmcode(vcheckm,vchecky) = cmcode(AG1M,AG1Y) and vcheckd < AG1D) then
        vdob = 1;
      endif;
    elseif valid(vcheckm) and vchecky < 9996 and cmcode(vcheckm,vchecky) < cmcode(AG1M,AG1Y) then
      vdob = 1;
    elseif vchecky < 9996 and vchecky < AG1Y then
      vdob = 1;
    endif;
  elseif valid(AG1M) and AG1Y < 9996 then
    if valid(vcheckm) and vchecky < 9996 and cmcode(vcheckm,vchecky) < cmcode(AG1M,AG1Y) then
      vdob = 1;
    elseif vchecky < 9996 and vchecky < AG1Y then
      vdob = 1;
    endif;
  elseif AG1Y < 9996 then
    if vchecky < 9996 and vchecky < AG1Y then
      vdob = 1;
    endif;
  endif;
end;

{ --------------------------------------------------------------------------- }
{ endmess
  If user is in addmode, it displays a menu with the options
  "Review Questionnaire" and "Next Questionnaire"
  Returns: 1 if user is in addmode or selects Next Questionnaire, 0 otherwise }

function endmess();
  { Returns true if response is REVIEW }
  endmess = (addmode and
             accept(
               {+EN} "End of Questionnaire",
                     "Review Questionnaire",
                     "Next Questionnaire  ") {EN+}
               {{FR} "Fin du Questionnaire",
                     "Vrifier le Questionnaire",
                     "Questionnaire suivant") {FR}}
               {{ES} "ES",
                     "ES",
                     "ES") {ES}}
                     <> 2);
end;

{ --------------------------------------------------------------------------- }
{ russian_convert
  Converts a letter from the cyrillic alphabet to the latin alphabet.
  The convert map is found in separate file									  }

function russian_convert();
  do l = 1 while l <= length(strip(alphavar))
    x = pos(alphavar[l:1],"");
    if x then
      alphavar[l:1] = "ABCDEFGHIJKLMNOPQRSTUVWXYZ"[x:1];
    endif;
  enddo;
end;

{ --------------------------------------------------------------------------- }
{ Function to check entry of alpha string variables }
{ alphachk
  Function to check entry of alpha string variables.
  Requirement: preceed with the statment alphavar = $
  Input variables:
  alphamask - The characters allowed and the order and position of these
  alphavar (set before calling the function) - the variable to be checked

  Checks that all the characters in the alphavar variable is found in alphamask
  and that they are in correct order. Repositions the characters before returning.
  If ? is found in string, makes sure that no other characters are present
  Returns: Repositioned string if valid, else 0

  Examples:
  alphavar    alphamask     returns
  "ABC"		  "ABCDEX"      "ABC   "
  "AC"		  "ABCDEX"      "A C   "
  "BEX"		  "ABCDEX"      " B  EX"
  "?"		  "ABCDEX"      "??????"
  "J"		  "ABCDEX"      0
  "ABQ"		  "ABCDEX"      0
  "?A"		  "ABCDEX"      0
  "BA"		  "ABCDEX"      0 (wrong order)                 }

function alphachk(alpha(26) alphamask);
{  russian_convert();}
  { first remove all blanks, and duplicate question marks }
  alphanew = "";
  qmark = 0;
  lx = 1;
  do l = 1 while l <= length(strip(alphavar))
    if alphavar[l:1] <> " " and (alphavar[l:1] <> "?" or not qmark) then
      alphanew[lx:1] = alphavar[l:1];
      lx = lx + 1;
      if alphavar[l:1] = "?" then
        qmark = 1;
      endif;
    endif;
  enddo;
  { aok = 0 - string is bad, aok = 1 - string is good }
  totlen = length(strip(alphamask));
  aok = 0;           { assume string is bad - for empty string }
  alphsize = length(strip(alphanew));
  if alphsize then   { not empty string }
    { check for "?" as only character }
    aok = (alphanew[1:1] = "?" and alphsize = 1);
    if !aok then     { if not a single "?", check string }
      aok = 1;       { now assume string is good until we know otherwise }
      l = 1;         { l is position in string of acceptable values }
      a = 1;         { a is position in input string }
      { loop while the string is still good and there are more letters }
      while aok and a <= alphsize do
        aok = pos(alphanew[a:1],alphamask[l:totlen-l+1]);
        if aok then     { letter is acceptable }
          l = l + aok;  { increment l to position after letter in string of acceptable values }
          a = a + 1     { increment a to next letter in input string }
        endif;
      enddo;
    endif;
  endif;
  alphachk = (!aok);    { alphachk = 0 - if string is good, = 1 - if string is bad }
  { now expand variables }
  if aok then
    do l = 1 while l <= length(strip(alphamask))
      if pos(alphamask[l:1],alphanew) then
        alphavar[l:1] = alphamask[l:1]
      elseif pos("?",alphanew) then
        alphavar[l:1] = "?"
      else
        alphavar[l:1] = " "
      endif;
    enddo;
  endif;
end;

PROC FL_ENTRY
preproc
maxmem = 50;      { maximum number of household members }
maxnet = 10;      { maximum number of nets set to 10 }
hhnum  = 0;       { last household number used }
wminage = 15;      { minimum age of eligible women }
wmaxage = 49;      { maximum age of eligible women }
mminage = 15;      { minimum age of eligible men }
mmaxage = 49;      { maximum age of eligible men }
minab  = 144;     { minimum age at birth in months = 12 years }
minam  = 48;      { minimum age at first marriage = 4 years }
mminab  = 144;     { minimum age at birth in months = 12 years }
mminam  = 48;      { minimum age at first marriage = 4 years }
chhlth = 4;       { maximum age at which child is included in child health module - excludes exact age 5 }
chlabl = 5;       { minimum age at which child is included in child labor module - includes exact age 5 }
chlabu = 14;      { maximum age at which child is included in child labor module - excludes exact age 15 }
mindi  = 20120101;{ replace "20111101" with earliest interview date in yyyymmdd format }
addmode = (demode() = ADD);
opid   = notappl;
cln   = tonumber(sysparm());
recode cln  => err;
     1-800  => 0;    { Give list of valid cluster numbers }
            => 1;
endrecode;
if err then
  errmsg(0010);
  endlevel;
endif;

inEntry = (demode() = add | demode() = modify);   { to run data entry in batch }

PROC HH
{ *** Level 1 *** }
preproc
  { Initialization prior to the entry of a household questionnaire }

  { Initialize the working woman's line number
    and the flags for the entry of eligible women }
  do i = 1 while i <= maxmem
    wenter(i) = 0;
    wcomp (i) = 0;
  enddo;

PROC FORMHH
if HH9 <> 1 then
  if endmess() then
    reenter HH17
  endif;
  endlevel
endif;

PROC HH1
if $ <> cln then
  errmsg(0010);
  reenter
endif;

PROC HH2
if addmode and HH2 < hhnum then
  errmsg(0012);
endif;
hhnum = HH2;

PROC HH5Y
recode HH5Y  :     HH5M        : HH5D => err;
   2011-2012 : 1,3,5,7,8,10,12 : 1-31 => 0;
   2011-2012 : 4,6,9,11        : 1-30 => 0;
        2011 : 2               : 1-28 => 0;
		2012 : 2               : 1-29 => 0;
             :                 :      => 1;
endrecode;
if err then
  {+EN} errmsg(0017, "Problem with Day/Month/Year combination"); {EN+}
  reenter
endif;
dd = (HH5Y*100 + HH5M)*100 + HH5D;
ss = sysdate("yyyymmdd");
if dd >= ss or dd < mindi then
  errmsg(0017,
        {+EN} "Date of interview either after current date or before the minimum date of interview" ); {EN+}
        {{FR} "Date de l'interview ou aprs la date actuelle ou avant la date minimum de l'interview" ); {FR}}
        {{ES} "ES" ); {ES}}
  reenter
endif;
di = cmcode(HH5M,HH5Y);

PROC HH6
recode HH1  : HH6 => err;
    001-100 :  1  => 0;
    101-200 :  2  => 0;
    201-300 :  1  => 0;
    301-400 :  2  => 0;
    401-500 :  1  => 0;
    501-600 :  2  => 0;
    601-700 :  1  => 0;
    701-800 :  2  => 0;
            :     => 1;
endrecode;
if err then
  errmsg(0011);
  reenter
endif;
PROC HH7
recode HH1  : HH7 => err;
    001-100 :  1  => 0;
    101-200 :  1  => 0;
    201-300 :  2  => 0;
    301-400 :  2  => 0;
    401-500 :  3  => 0;
    501-600 :  3  => 0;
    601-700 :  4  => 0;
    701-800 :  4  => 0;
            :     => 1;
endrecode;
if err then
  errmsg(0011);
  reenter
endif;

PROC HH9
if $ <> 1 then
  skip to HH16
endif;

PROC HH11
if HH10 > $ then
  errmsg (0018);
  reenter;
endif;

PROC HH12
if HH12 > HH11 then
  errmsg(0016);
  reenter
endif;

PROC HH13
if $ > HH12 then
  errmsg(0014);
  reenter
endif;

PROC HH13A
if HH12 + HH13A > HH11 then
  errmsg(0016);
  reenter
endif;
PROC HH13B
if $ > HH13A then
  errmsg(0015);
  reenter
endif;
PROC HH14
if HH12 + HH13A + HH14 > HH11 then
  errmsg(0016);
  reenter
endif;

PROC HH15
if $ > HH14 then
  errmsg(0013);
  reenter
endif;

PROC HH17
preproc
if addmode & special(visualvalue($)) & opid <> notappl then
  $ = opid;
endif;

postproc
opid = $;

PROC HH18H
preproc
if !inentry and HH9 <> 1
	then endgroup;
endif;	
PROC FORMHL_ROSTER

for i in FORMHL_ROSTER

  { Check the head of household is of age 15 or above }
  if HL3 = 1 and HL6 < 15 then
    errmsg(0147,i,HL6);
  endif;

  { Check that HH member identified by HL12 could be child's mother }
  if HL12 >= 1 then
    if HL4(HL12) <> 2 or HL6(HL12) < HL6+(minab/12) then
      errmsg(0164,i,HL4(HL12),HL6(HL12), {+EN} "Mother", {EN+}
                                         {{FR} "Mre", {FR}}
                                         {{ES} "ES", {ES}}
             "HL12",HL12);
    endif;
  endif;

  { Check that HH member identified by HL14 could be child's father }
  if HL14 >= 1 then
    if HL4(HL14) <> 1 or HL6(HL14) < HL6+(minab/12) then
      errmsg(0164,i,HL4(HL14),HL6(HL14), {+EN} "Father", {EN+}
                                         {{FR} "Pre", {FR}}
                                         {{ES} "ES", {ES}}
             "HL14",HL14);
    endif;
  endif;

  { Check the spouse of head of household is of opposite sex }
  if HL3 = 2 and HL4 = HL4(1) then
    errmsg(0142,i);

  { Check children of head of household are at least 12 years younger }
  elseif HL3 = 3 and HL6(1) < HL6+(minab/12) then
    errmsg(0143,minab/12,i);

  { Check grandchildren of head of household are at least 24 years younger }
  elseif HL3 = 5 and HL6(1) < HL6+2*(minab/12) then
    errmsg(0145,2*minab/12,i);

  { Check parents of head of household are at least 12 years older }
  elseif HL3 = 6 and HL6(1)+(minab/12) > HL6 then
    errmsg(0146,minab/12,i);
  endif;
enddo;

x = count(FORMHL_ROSTER where HL7 > 0);
if HH12 <> x then
  errmsg(0110, {+EN} "Women 15-49", {EN+}
               {{FR} "Femmes de 15-49 ans", {FR}}
               {{ES} "ES", {ES}}
               x,"HH12",HH12);
  reenter HL3(1);
endif;

x = count(FORMHL_ROSTER where HL7A > 0);
if HH13A <> x then
  errmsg(0110, {+EN} "Men 15-49", {EN+}
               {{FR} "Hommes de 15-49 ans", {FR}}
               {{ES} "ES", {ES}}
               x,"HH13A",HH13A);
  reenter HL3(1);
endif;

x = count(FORMHL_ROSTER where HL9 > 0);
if HH14 <> x then
  errmsg(0110, {+EN} "Children 0-4", {EN+}
               {{FR} "Enfants de 0-4 ans", {FR}}
               {{ES} "ES", {ES}}
               x,"HH14",HH14);
  reenter HL3(1);
endif;

x = count( FORMHL_ROSTER where HL3 = 1 );
if x <> 1 then
   errmsg( 0104,x);
   reenter HL3(1);
endif;

PROC HL1
preproc
if curocc(FORMHL_ROSTER) > HH11 then
  endgroup
endif;

if inEntry then
  do i = 1 while i <= maxmem
    if i <= HH11 then
      HL1(i) = i
    else
      HL1(i) = notappl
    endif;
  enddo;
endif;

PROC HL3
{ Head of household must be on first line }
if ($ = 1) <=> (HL1 <> 1) then
  errmsg(0141);
  reenter;
endif;

PROC HL5Y
if HL5Y < 9997 then
  ldob = setlb(HL5M,HL5Y,0);
  udob = setub(HL5M,HL5Y,9999);
  if ldob > di then
    errmsg(0031);
    reenter
  endif;
else
  udob = di;
  ldob = 0;
endif;

PROC HL6
if HL6 < 95 then
  { Lower bound of CMC date of birth }
  t = adjlba(ldob,udob,di,di,HL6);
  if t < 0 then
    errmsg(0031);
    {reenter}
  else
    ldob = t
  endif;
  { Upper bound of CMC date of birth }
  t = adjuba(ldob,udob,di,di,HL6);
  if t < 0 then
    errmsg(0031);
    {reenter}
  else
    udob = t
  endif;
elseif HL6 = 95 then
  if !(HL5 in 1900:HH5Y-95) then
    errmsg(0031);
    {reenter}
  endif;
endif;

PROC HL7
preproc
if not (HL4 = 2 and HL6 in wminage:wmaxage) then
  HL7 = 0;
  noinput;
endif;

postproc
if HL4 = 2 and HL6 in wminage:wmaxage then
  if HL7 <> HL1 then
    errmsg(0101);
    reenter
  endif;
else
  if HL7 <> 0 then
    errmsg(0102);
    reenter
  endif;
endif;

PROC HL7A
preproc
if not (HL4 = 1 and HL6 in mminage:mmaxage) then
  HL7A = 0;
  noinput;
endif;

postproc
if HL4 = 1 and HL6 in mminage:mmaxage then
  if HL7A <> HL1 then
    errmsg(0101);
    reenter
  endif;
else
  if HL7A <> 0 then
    errmsg(0102);
    reenter
  endif;
endif;
PROC HL8
preproc
if not (HL6 in chlabl:chlabu) then
  HL8 = 0;
  noinput;
endif;

postproc
if HL6 in chlabl:chlabu then
  if HL8 = 0 or HL8 = HL1 then
    errmsg(0121);
    reenter
  elseif HL8 > HH11 then
    errmsg(0120,HL8,HH11);
    reenter
  endif;
else
  if HL8 <> 0 then
    errmsg(0122);
    reenter
  endif;
endif;

PROC HL9
preproc
if HL6 > chhlth then
  HL9 = 0;
  noinput;
endif;

postproc
if HL6 <= chhlth then
  if HL9 = 0 or HL9 = HL1 then
    errmsg(0131);
    reenter
  elseif HL9 > HH11 then
    errmsg(0130,HL9,HH11);
    reenter
  endif;
else
  if HL9 <> 0 then
    errmsg(0132);
    reenter
  endif;
endif;

PROC HL11
preproc
if HL6 > 17 then
  skip to next HL1
endif;

postproc
if HL11 <> 1 then
  skip to HL13
endif;

PROC HL12
if HL12 >= 1 then
  if valid(HL12) and HL12 > HH11 then
    errmsg(0161, {+EN} "Mother's", {EN+}
                 {{FR} "de la mre", {FR}}
                 {{ES} "ES", {ES}}
                 "HL12",HL12,HH11);
    reenter;
  elseif HL12 = HL1 then
    errmsg(0162, {+EN} "Mother's", {EN+}
                 {{FR} "de la mre", {FR}}
                 {{ES} "ES", {ES}}
                 "HL12",HL12,HL1);
    reenter;
  elseif HL8 <> 0 then
    if HL12 <> HL8 then
      errmsg(0163,HL12,"HL8",HL8);
    endif;
  elseif HL9 <> 0 then
    if HL12 <> HL9 then
      errmsg(0163,HL12,"HL9",HL9);
    endif;
  endif;
endif;

PROC HL13
if HL13 <> 1 then
  skip to next HL1
endif;

PROC HL14
if HL14 >= 1 then
  if valid(HL14) and HL14 > HH11 then
    errmsg(0161, {+EN} "Father's", {EN+}
                 {{FR} "du pre", {FR}}
                 {{ES} "ES", {ES}}
                 "HL14",HL14,HH11);
    reenter;
  elseif HL14 = HL1 then
    errmsg(0162, {+EN} "Father's", {EN+}
                 {{FR} "du pre", {FR}}
                 {{ES} "ES", {ES}}
                 "HL14",HL14,HL1);
    reenter;
  endif;
endif;

PROC ED1
preproc
if curocc(FORMED_ROSTER) > HH11 then
  endgroup
endif;

if inEntry then
  do i = 1 while i <= maxmem
    if i <= HH11 then
      ED1(i) = i;
    else
      ED1(i) = notappl;
    endif;
  enddo;
endif;

PROC ED3
preproc
if HL6(ED1) < 5 then
  skip to next ED1
endif;

postproc
if ED3 <> 1 then
  skip to next ED1
endif;

PROC ED4A
if ED4A = 0 then
  skip to ED5;
endif;

PROC ED4B
recode ED4A : $         => err; { Fix maximum grade for each possible level }
            : 97,98,99    => 0;   { Inconsistent, missing, DK grade }
          1 : 0-6         => 0;   { Primary }
          2 : 0-6         => 0;   { Secondary }
          3 : 0-5         => 0;   { Higher }
          8 :             => 0;   { DK level }
          9 :             => 0;   { Missing level }
            :             => 1;
endrecode;
if err then
  errmsg(0090);
  { reenter }
endif;

PROC ED5
preproc
if HL6(ED1) > 24 then
  skip to next ED1
endif;

postproc
if ED5 <> 1 then
  skip to ED7
endif;

PROC ED6A
if ED6A <= 3 and ED4A <= 3 and ED6A > ED4A then
  errmsg(0091,ED6A,ED4A);
  reenter;
endif;

if ED6A = 0 then
  skip to ED7;
endif;

PROC ED6B
recode ED6A : $           => err; { Fix maximum grade for each possible level }
            : 97,98,99    => 0;   { Inconsistent, missing, DK grade }
          1 : 1-6         => 0;   { Primary }
          2 : 1-6         => 0;   { Secondary }
          3 : 1-5         => 0;   { Higher }
          8 :             => 0;   { DK level }
          9 :             => 0;   { Missing level }
            :             => 1;
endrecode;
if err then
  errmsg(0090);
  reenter
endif;

{ Compare current grade and level to max grade and level }
if (ED4A = ED6A) and valid(ED6B) and valid(ED4B) and ED6B > ED4B+1 then
  errmsg(0092,ED6B,ED4B);
endif;

PROC ED7
if ED7 <> 1 then
  skip to next ED1
endif;

PROC ED8A
if ED8A <= 3 and ED4A <= 3 and ED8A > ED4A then
  errmsg(0093,ED8A,ED4A);
  reenter;
endif;

if ED8A = 0 then
  skip to next ED1
endif;

PROC ED8B
recode ED8A : $           => err; { Fix maximum grade for each possible level }
            : 97,98,99    => 0;   { Inconsistent, missing, DK grade }
          1 : 1-6         => 0;   { Primary }
          2 : 1-6         => 0;   { Secondary }
          3 : 1-5         => 0;   { Higher }
          8 :             => 0;   { DK level }
          9 :             => 0;   { Missing level }
            :             => 1;
endrecode;
if err then
  errmsg(0090);
  reenter
endif;

{ Compare last year's grade and level to max grade and level }
if ED4A = ED8A and valid(ED8B) and valid(ED4B) and ED8B > ED4B+1 then
  errmsg(0094,ED8B,ED4B);
{ Compare this year's grade and level to last year's grade and level }
elseif (ED6A = ED8A and valid(ED8B) and valid(ED6B) and ED8B > ED6B+1) or
       (ED6A in 0:3 and ED8A in 0:3 and ED8A > ED6A) then
  errmsg(0095,ED8A,ED8B,ED6A,ED6B);
endif;
PROC WS1
if $ in 11,12,13 then
  skip to WS6
elseif $ in 14:81,96,99 then
  skip to WS3
{ elseif $ = 91 then { bottled water }
  skip to WS2 }
endif;

PROC WS2
if $ in 11,12,13 then
  skip to WS6
endif;

PROC WS3
if $ in 1,2 then
  skip to WS6
endif;

PROC WS6
if $ <> 1 then
  skip to WS8
endif;

PROC WS7
alphavar = $;
if alphachk("ABCDEFXZ") then
  errmsg(9998);
  reenter
else
  $ = alphavar;
endif;
{ Check "Don't Know" is only response }
if pos("Z",$) & alphsize > 1 then
  errmsg(9996);
  reenter
endif;

PROC WS8
if $ = 95 then
  endgroup
endif;

PROC WS9
if $ <> 1 then
  endgroup
endif;

PROC WS10
if $ <> 1 then
  endgroup
endif;

PROC HC6
if $ in 1:5,95 then
  skip to HC8A
endif;

PROC HC11
if $ <> 1 then
  skip to HC13
endif;

PROC HC13
if $ <> 1 then
  skip to HC15;
endif;

PROC HC14F
if HC13=1 and HC14A=0 and HC14B=0 and HC14C=0 and HC14D=0 and HC14E=0 and HC14F=0 then
  errmsg (0170);
  reenter;
endif;
PROC TN1
if TN1 <> 1 then
  endgroup;
endif;


PROC TNLN
preproc
if curocc(FORMTN_ROSTER) > TN2 then
  endgroup
endif;

if inEntry then
  do i = 1 while i <= maxnet
    if i <= TN2 then
      TNLN(i) = i;
    else
      TNLN(i) = notappl;
    endif;
  enddo;
endif;

PROC TN6
if TN5 in 11:18 then
  skip to TN11;
elseif TN5 in 21:28 then
  skip to TN9;
endif;

PROC TN9
if $ <> 1 then
  skip to TN11
endif;
PROC TN11
if $ <> 1 then
   skip to next TNLN
endif;

PROC TN12_1
onfocus
setnet(GetSymbol(),curocc());
set attributes($) assisted on;
setvalueset($,codes,labels);

postproc
if checknet($,GetSymbol(),curocc()) then
  reenter
elseif $ = 90 then
  skip to next TNLN
endif;

PROC TN12_2
onfocus
setnet(GetSymbol(),curocc());
set attributes($) assisted on;
setvalueset($,codes,labels);

postproc
if checknet($,GetSymbol(),curocc()) then
  reenter
elseif $ = 90 then
  skip to next TNLN
endif;

PROC TN12_3
onfocus
setnet(GetSymbol(),curocc());
set attributes($) assisted on;
setvalueset($,codes,labels);

postproc
if checknet($,GetSymbol(),curocc()) then
  reenter
elseif $ = 90 then
  skip to next TNLN
endif;

PROC TN12_4
onfocus
setnet(GetSymbol(),curocc());
set attributes($) assisted on;
setvalueset($,codes,labels);

postproc
if checknet($,GetSymbol(),curocc()) then
  reenter
elseif $ = 90 then
  skip to next TNLN
endif;
PROC IR1
if $ <> 1 then
  endgroup
endif;

PROC IR2
alphavar = $;
if alphachk("ABCXZ") then
  errmsg(9998);
  reenter
else
  $ = alphavar;
endif;
{ Check "Don't Know" is only response }
if pos("Z",$) & alphsize > 1 then
  errmsg(9996);
  reenter
endif;

PROC CL1
preproc
if curocc(FORMCL_ROSTER) > HH11 then
  endgroup
endif;

if inEntry then
  do i = 1 while i <= maxmem
    if i <= HH11 then
      CL1(i) = i;
    else
      CL1(i) = notappl
    endif;
  enddo;
endif;

PROC CL3
preproc
if not HL6(CL1) in chlabl:chlabu then
  skip to next CL1
endif;

postproc
if $ >= 3 then
  skip to CL5
endif;

PROC CL5
if $ <> 1 then
  skip to CL7
endif;

PROC CL6
if NAtoZero(CL4) + NAtoZero(CL6) > 80 then
  errmsg(0201);
endif;

PROC CL7
if $ <> 1 then
	skip to CL9
endif;

PROC CL8
if NAtoZero(CL4) + NAtoZero(CL6) + NAtoZero(CL8) > 80 then
  errmsg(0201);
endif;

PROC CL9
if $ <> 1 then
  skip to next CL1
endif;

PROC CL10
if NAtoZero(CL4) + NAtoZero(CL6) + NAtoZero(CL8) + NAtoZero(CL10)> 80 then
  errmsg(0201);
endif;

PROC FORMCD
preproc
if count(FORMHL_ROSTER where HL6 in  2:14) = 0 then
  endgroup
endif;

PROC CD6
x = count(FORMHL_ROSTER where HL6 in 2:14);
if $ <> x then
  errmsg(0301, x);
reenter;
endif;

PROC CD8
if $ > CD6 then
  errmsg(0302,$,CD6);
elseif CD6 = 1 and $ <> 1 then
  errmsg(0303);
endif;

PROC CD9
if valid($) then
  if $ > HH11 then
    errmsg(0304,$,HH11);
    reenter;
  elseif !(HL6($) in 2:14) then
    errmsg(0305,HL6($));
    reenter;
  endif;
endif;


PROC CD_FLAG
preproc
  { Kish grid }
  KishGrid(0) = "12243654";
  KishGrid(1) = "11314165";
  KishGrid(2) = "12125276";
  KishGrid(3) = "11231317";
  KishGrid(4) = "12342428";
  KishGrid(5) = "11113531";
  KishGrid(6) = "12224642";
  KishGrid(7) = "11335153";
  KishGrid(8) = "12141264";
  KishGrid(9) = "11212375";
  kount = 0;
  for i in FORMHL_ROSTER do
    if HL6 in 2:14 then
      kount = kount + 1;
      if kount = CD8 then
        CDline = HL1;
      endif;
    endif;
  enddo;
  CD_FLAG = 2 - (CD8 = tonumber(Kishgrid(HH2%10)[CD6:1]) & CD9 = CDline);

PROC HW1
if $ <> 1 then
  skip to HW4
endif;

PROC HW3
alphavar = $;
if alphachk("ABCDY") then
  errmsg(9998);
  reenter
else
  $ = alphavar;
endif;
{ Check "None" is only response }
if pos("Y",$) then
  if alphsize > 1 then
    errmsg(9996);
    reenter
  endif;
else
  endgroup;
endif;

PROC HW4
if $ <> 1 then
  endgroup
endif;

PROC HW5
alphavar = $;
if alphachk("ABCDY") then
  errmsg(9998);
  reenter
else
  $ = alphavar;
endif;
{ Check "Not able/Does not want to show" is only response }
if pos("Y",$) & alphsize > 1 then
  errmsg(9996);
  reenter
endif;

PROC HH19H
preproc
if !inentry and HH9 <> 1
	then endgroup;
endif;	
PROC HH19M
if Valid(HH18H) and Valid(HH18M) and Valid(HH19H) and Valid(HH19M) then
  if (HH18H*60+HH18M)>(HH19H*60+HH19M)then
    errmsg(9990);
    reenter
  endif;
endif;

PROC WMMNCH
{ *** Level 2 *** }
preproc
  { Initialization prior to an individual questionnaire }
  xline = 0;
  { Find the next eligible woman to enter }
  do i = 1 while i <= HH11
    if HL7(i) and wenter(i) = 0 then
      xline = i;
      break;  { Having found a woman exit the while-do loop }
    endif;
  enddo;
  if !xline then
    { Find the next eligible man to enter }
    do i = 1 while i <= HH11
      if HL7A(i) and wenter(i) = 0 then
        xline = i;
        break;  { Having found a man exit the while-do loop }
      endif;
    enddo;
  endif;
      if !xline  then
    { Find the next eligible child to enter }
    do i = 1 while i <= HH11
      if HL9(i) and wenter(i) = 0 then
        xline = i;
        break;  { Having found a child exit the while-do loop }
      endif;
    enddo;
  endif;
  
  { Quit level 2 if no individual questionnaires to enter }
  if !xline then
    endlevel
  endif;


postproc
   { Update the entry flag for individual questionnaire just entered }
  if xline then
    if HL7(xline) <> 0 then
      wenter(xline) = 1;
      wcomp (xline) = (WM7 = 1);
    elseif HL7A(xline) <> 0 then
      wenter(xline) = 2;
      wcomp (xline) = (MWM7 = 1);
    elseif HL9(xline) <> 0 then
      wenter(xline) = 3;
      wcomp (xline) = (UF9 = 1);
    endif;
  endif;

  { Check the number of individual questionnaires entered and
    quit level 2 if no more to enter }
  xwomen = 0;
  xwc = 0;
  do varying i = 1 until i > HH11
    if wenter(i) = 1 then
      xwomen = xwomen + 1;
      if wcomp(i) = 1 then
        xwc = xwc + 1;
      endif;
    endif;
  enddo;
  xmen = 0;
  xmc = 0;
  do varying i = 1 until i > HH11
    if wenter(i) = 2 then
      xmen = xmen + 1;
      if wcomp(i) = 1 then
        xmc = xmc + 1;
      endif;
    endif;
  enddo;
  xchild = 0;
  xcc = 0;
  do varying i = 1 until i > HH11
    if wenter(i) = 3 then
      xchild = xchild + 1;
      if wcomp(i) = 1 then
        xcc = xcc + 1;
      endif;
    endif;
  enddo;

  if xwomen = HH12 and xmen = HH13A and xchild = HH14 then
    { Check counts of complete women and children too }
    if !(xwc = HH13 and xmc = HH13B and xcc = HH15) then
      errmsg(0020,xwc,HH13,xmc,HH13B,xcc,HH15); 
       endif;
     endif;
PROC LN
preproc
LN = xline;

postproc
if HL7A(LN) <> 0 then
  skip to MWM1 {FORMMWB} {With entry in batch, need to skip to a field, not a form}
elseif HL9(LN) <> 0 then
  skip to UF1 {FORMCH} {With entry in batch, need to skip to a field, not a form}
endif;

PROC FORMWM
if WM7 <> 1 then
  if endmess() then
    reenter WM9
  endif;
  endlevel
endif;

PROC WM1
preproc
WM1 = HH1;
WM2 = HH2;

PROC WM4
preproc
if addmode then
  display(concat( {+EN} "Questionnaire for Woman ", {EN+}
                  {{FR} "Questionnaire pour la Femme ", {FR}}
                  {{ES} "ES", {ES}}
                  edit("99", LN)));
endif;

postproc
if WM4 <> LN then
  errmsg(1000, LN);
  reenter
endif;

PROC WM6Y
recode WM6Y   :     WM6M        : WM6D => err;
   2009-2012 : 1,3,5,7,8,10,12 : 1-31 => 0;
   2009-2012 : 4,6,9,11        : 1-30 => 0;
   2009-2011 : 2               : 1-28 => 0;
        2012 : 2               : 1-29 => 0;
             :                 :      => 1;
endrecode;
if err then
  errmsg(0017, {+EN} "Problem with Day/Month/Year combination"); {EN+}
               {{FR} "Problme avec la combinaison du Jour/Mois/Anne"); {FR}}
               {{ES} "ES"); {ES}}
  reenter
endif;
dd = (HH5Y*100 + HH5M)*100 + HH5D;
ddw= (WM6Y*100 + WM6M)*100 + WM6D;
ss = sysdate("yyyymmdd");
if ddw >= ss or ddw < dd then
  errmsg(0017, {+EN} "Date of interview either after current date or before minimum date of interview"); {EN+}
               {{FR} "Date de l'interview est ou aprs la date actuelle ou avant la date minimum de l'interview"); {FR}}
               {{ES} "ES"); {ES}}
  reenter
endif;
diwm = cmcode(WM6M,WM6Y);

PROC WM9
preproc
if addmode & special(visualvalue($)) & opid <> notappl then
  $ = opid;
endif;
PROC WM10H
preproc
if !inentry and WM7 <> 1
	then endgroup;
endif;	
PROC WB1M
if WB1M <> HL5M(LN) then
  errmsg(1004,WB1M,HL5M(LN));
endif;

PROC WB1Y
if WB1Y <> HL5Y(LN) then
  errmsg(1005,WB1Y,HL5Y(LN));
endif;
udob = diwm - wminage*12;
ldob = diwm - wmaxage*12 - 11;
if WB1Y < 9997 then
  ldob = setlb(WB1M,WB1Y,0);
  udob = setub(WB1M,WB1Y,9999);
  if udob < diwm - wmaxage*12 - 11 or ldob > diwm - wminage*12 then
    errmsg(1001);
  { reenter }
  endif;
endif;

PROC WB2
if WB2 <> HL6(LN) then
  errmsg(1002,WB2,HL6(LN));
endif;
{ Lower bound of CMC date of birth }
t = adjlba(ldob,udob,diwm,diwm,WB2);
if t < 0 then
  errmsg(1003);
{ reenter }
else
  ldob = t
endif;
{ Upper bound of CMC date of birth }
t = adjuba(ldob,udob,diwm,diwm,WB2);
if t < 0 then
  errmsg(1003);
{ reenter }
else
  udob = t
endif;

PROC WB3
if WB3 <> ED3(LN) and ED4A(LN) <> 0 then
  errmsg(1011,ED3(LN),WB3);
endif;
if WB3 <> 1 then
  skip to WB7
endif;
PROC WB4
if WB4 <> ED4A(LN) then
  errmsg(1012,ED4A(LN),WB4);
endif;

if WB4 = 0 then
  skip to WB7
endif;

PROC WB5
if WB5 <> ED4B(LN) then
  errmsg(1013,ED4B(LN),WB5);
endif;
recode WB4  : $           => err; { Fix maximum grade for each possible level }
            : 97,98,99    => 0;   { Inconsistent, missing, DK grade }
          1 : 0-8         => 0;   { Primary }
          2 : 0-4         => 0;   { Secondary }
          3 : 0-6         => 0;   { Higher }
          8 :             => 0;   { DK level }
          9 :             => 0;   { Missing level }
            :             => 1;
endrecode;
if err then
  errmsg(1014);
  { reenter }
endif;
{ WB6 Filter }
if WB4 in 2,3 then
  endgroup
endif;

PROC MT2
preproc
if WB7 = 1 or WB7 = 5 then
	skip to MT3;
endif;
PROC MT6
preproc
if WB2 in 25:49 then
	endgroup;
endif;	

postproc
if $ <> 1 then
	skip to MT9;
endif;	
PROC MT7
if $ <> 1 then
	skip to MT9;
endif;	
PROC MT9
if $ <> 1 then
	endgroup;
endif;	
PROC MT10
if $ <> 1 then
	endgroup;
endif;	
PROC CM1
if $ <> 1 then
  skip to CM8
endif;

{{BH} skip to CM3; {BH}} { If using birth history, skip to CM3 }

PROC CM2Y
ldobfc = ldob + minab;
udobfc = diwm;
if CM2Y < 9997 then
  ldobfc = setlb(CM2M,CM2Y,0);
  udobfc = setub(CM2M,CM2Y,9999);
  if udobfc < ldob + minab then
    errmsg(1101,int(minab/12));
  elseif ldobfc > diwm then
    errmsg(1102);
  endif;
  skip to CM4
endif;

PROC CM3
if WB2 - CM3 < (minab/12) then
  errmsg(1103,minab/12);
endif;

PROC CM4
if $ <> 1 then
  skip to CM6
endif;

PROC CM5B
{ Check for at least one child living at home - otherwise CM3 must be 2 }
if CM5A = 0 and CM5B = 0 then
  errmsg(1110, "CM4");
  reenter
endif;

PROC CM6
if $ <> 1 then
  skip to CM8
endif;

PROC CM7B
{ Check for at least one child living away - otherwise CM6 must be 2 }
if CM7A = 0 and CM7B = 0 then
  errmsg(1110, "CM6");
  reenter
endif;

PROC CM8
if $ <> 1 then
  skip to CM10
endif;

PROC CM9B
{ Check for at least one child who died - otherwise CM8 must be 2 }
if CM9A = 0 and CM9B = 0 then
  errmsg(1110, "CM8");
  reenter
endif;

PROC CM10
{ Count up total children ever born }
x = NAtoZero(CM5A)+NAtoZero(CM5B)+
    NAtoZero(CM7A)+NAtoZero(CM7B)+
    NAtoZero(CM9A)+NAtoZero(CM9B);
{ Check count of children ever born with total }
if x <> CM10 then
  errmsg(1111, CM10, x);
  reenter;
endif;

if $ = 0 then
  skip to IS2
endif;

{{BH} endgroup; {BH}} { If using birth history, skip to birth history }


PROC CM12Y
ldoblc = ldobfc;
udoblc = diwm;
if CM12Y < 9997 then
  ldoblc = setlb(CM12M,CM12Y,0);
  udoblc = setub(CM12M,CM12Y,9999);
  if udoblc < ldob + minab then
    errmsg(1121,int(minab/12));
  elseif ldoblc > diwm then
    errmsg(1122);
  endif;
endif;

if CM10 = 1 then
  if (CM12Y <> CM2Y or CM12M <> CM2M or CM12D <> CM2D) then
    errmsg(1123);
  endif;
else
  if ldobfc > udoblc then
    errmsg(1124);
  endif;
endif;

PROC CM13
{ Check if birth in last 24 months }
{ Note use of parentheses for correct check }
{ {BH}} { if not using birth history }
if CM12Y in WM6Y,WM6Y-1 or
  (CM12Y = WM6Y-2 and ((CM12M in WM6M:12) or
  (CM12M = WM6M   and   CM12D in WM6D:31))) then
{{BH} }
{{BH} { if using birth history - move CM13 after birth history }
if BH4Y(CM10) in WM6Y,WM6Y-1 or
  (BH4Y(CM10) = WM6Y-2 and BH4M(CM10) in WM6M:12) then
{BH}}
  if CM13 <> {+EN} "Y" {EN+}
             {{FR} "O" {FR}}
             {{ES} "S" {ES}}
  then
    errmsg(1131);
    reenter
  endif;
else
  if CM13 <> "N" then
    errmsg(1132);
    reenter
  endif;
endif;

if CM13 = "N" then
  skip to IS2 {With entry in batch, need to skip to a field, not a form}
endif;

PROC FORMBH
postproc
n = totocc(FORMBH_ROSTER);

{ Check counts of children living at home }
x = count( FORMBH_ROSTER where BH3 = 1 & BH5 = 1 & BH7 = 1 );
if noteq( x, CM5A ) then
  errmsg( 1156, {+EN} "Sons living at home", {EN+}
                {{FR} "Fils qui vivent  la maison", {FR}}
                {{ES} "ES", {ES}}
                "CM5A", CM5A, x );
  reenter BH5(n)
endif;
x = count( FORMBH_ROSTER where BH3 = 2 & BH5 = 1 & BH7 = 1 );
if noteq( x, CM5B ) then
  errmsg( 1156, {+EN} "Daughters living at home", {EN+}
                {{FR} "Filles qui vivent  la maison", {FR}}
                {{ES} "ES", {ES}}
                "CM5B", CM5B, x );
  reenter BH5(n)
endif;

{ Check counts of children living away }
x = count( FORMBH_ROSTER where BH3 = 1 & BH5 = 1 & BH7 = 2 );
if noteq( x, CM7A ) then
  errmsg( 1156, {+EN} "Sons living away from home", {EN+}
                {{FR} "Fils qui vivent hors du domicile", {FR}}
                {{ES} "ES", {ES}}
                "CM7A", CM7A, x );
  reenter BH5(n)
endif;
x = count( FORMBH_ROSTER where BH3 = 2 & BH5 = 1 & BH7 = 2 );
if noteq( x, CM7B ) then
  errmsg( 1156, {+EN} "Daughters living away from home", {EN+}
                {{FR} "Filles qui vivent hors du domicile", {FR}}
                {{ES} "ES", {ES}}
                "CM7B", CM7B, x );
  reenter BH5(n)
endif;

{ Check counts of children who have died }
x = count( FORMBH_ROSTER where BH3 = 1 & BH5 = 2 );
if noteq( x, CM9A ) then
  errmsg( 1156, {+EN} "Boys who died", {EN+}
                {{FR} "Garons dcds", {FR}}
                {{ES} "ES", {ES}}
                "CM9A", CM9A, x );
  reenter BH5(n)
endif;
x = count( FORMBH_ROSTER  where BH3 = 2 & BH5 = 2 );
if noteq( x, CM9B ) then
  errmsg( 1156, {+EN} "Girls who died", {EN+}
                {{FR} "Filles dcdes", {FR}}
                {{ES} "ES", {ES}}
                "CM9B", CM9B, x );
  reenter BH5(n)
endif;

if CM10 then
  { Checking of minimum interval between births }
  lb = CM10 - twincode(CM10) - (twincode(CM10) = 0);
  do i = 1 while i <= lb by 1
    do j = i + 1 while twincode(j) > 1 enddo;
    t = adjlbi( ldc(i), udc(i), ldc(j), udc(j), 7 );
    if t < 0 then
      errmsg( 1157, i, BH4M(i), BH4Y(i), j, BH4M(j), BH4Y(j) );
    else
      ldc(j) = t;
    endif;
    t = adjubi( ldc(i), udc(i), ldc(j), udc(j), 7 );
    if t < 0 then
      errmsg( 1157, i, BH4M(i), BH4Y(i), j, BH4M(j), BH4Y(j) );
    else
      udc(i) = t;
    endif;
  enddo;
endif;

do i = 1 while i <= HH11
  if HL12(i) = LN & count( FORMBH_ROSTER where BH8 = i ) <> 1 then
    if addmode then
      errmsg( 1152, i )
    endif;
  endif;
enddo;

PROC BHLN
preproc
{ Initialize line numbers of each child ... }
if inEntry then
  do i = 1 while i <= maxchild
    if i <= CM10 then
      BHLN(i) = i;
    else
      BHLN(i) = notappl;        { blank out unused lines }
    endif;
  enddo;
endif;

{ Check for end of birth history }
if curocc() > CM10 then    { to run in-Batch }
  endgroup
endif;

PROC BH2
{ Set up twin code variable coded as follows:
    0 - Single birth
    1 - 1st of multiple
    2 - 2nd of multiple
    3 - 3rd of multiple
    etc.
    This variable easier to use in controlling twins.
}
if $ = 1 then
  twincode(BHLN) = 0
elseif BHLN = 1 then
  twincode(1)    = 1
else
  twincode(BHLN) = twincode(BHLN-1) + 1
endif;

PROC BH4Y
{ Check date of birth before interview }
if afterint( BH4M, $ ) then
  errmsg( 1142 );
  reenter;
endif;

prev = BHLN - 1;
{ Update twin code variable in case of two pairs of twins together }
{ Twincode is 0-Single birth, 1-1st of multiple, 2-2nd of multiple, ... }
if BH2 = 2 & prev & twincode(prev) >= 2 then
  if ($ <> $(prev) | BH4M <> BH4M(prev)) then
    twincode(BHLN) = 1
  endif
endif;

{ Check twin codes }
{ Last child can not be 1st of multiple birth }
if twincode(BHLN) = 1 then
  if BHLN = CM10 then
    errmsg( 1140 );
    reenter BH2
  endif
{ Current twin code must be 1 higher than previous }
elseif twincode(BHLN) >= 2 then
  if BHLN = 1 | twincode(prev) <> twincode(BHLN) - 1 then
    errmsg( 1140 );
    reenter BH2
  endif
{ Previous birth is first of multiple, but current is single birth }
elseif BHLN > 1 & twincode(prev) = 1 then
  errmsg( 1140 );
  reenter BH2
endif;

{ Check months and years match for twins }
if twincode(BHLN) > 1 & (BH4M <> BH4M(prev) | $ <> $(prev)) then
  errmsg( 1143 );
  reenter
endif;

{ Find prior birth with year of birth to check order }
do i = BHLN-1 while i & ($(i) = missing | $(i) > WM6Y) by (-1) enddo;
{ Check births are given in order }
if i & validyr($) &
  ( $ < $(i) |
   ($ = $(i) & valid(BH4M(i)) & BH4M < BH4M(i))
  ) then
  errmsg( 1144 );
  reenter;
endif;

{ Check that twin code is correct when dates are identical }
if BHLN > 1 & validyr($) & valid(BH4M) &
  ($ = $(prev) & BH4M = BH4M(prev)) & BH2 = 1 then
  errmsg( 1145 );
  reenter BH2
endif;

{ Initialize logical ranges for date of birth of child }
if validyr($) then
  ldc(BHLN) = setlb( BH4M, $, 0 );
  udc(BHLN) = setub( BH4M, $, 9999 );
else
  ldc(BHLN) = ldb + minab;
  udc(BHLN) = di;
endif;

PROC BH5
if $ <>1 then
  skip to BH9U
endif;

PROC BH6
{ Check that twins have same age if both are alive }
if twincode(BHLN) >= 2 then
  j = default;
  do i = BHLN - twincode(BHLN) + 1 while i < BHLN
    if BH5(i) = 1 then
      j = $(i);
    endif;
  enddo;
  if j <> default & j <> $ then
    errmsg( 1146 );
    reenter
  endif;
endif;

{ Adjust ranges for date of birth of child }
if valid($) then
  { Lower bound of CMC date of birth }
  t = ndjlba( ldc(BHLN), udc(BHLN), di, di, $ );
  if t < 0 then
    errmsg( 1147 );
    reenter
  else
    ldc(BHLN) = t
  endif;
  { Upper bound of CMC date of birth }
  t = adjuba( ldc(BHLN), udc(BHLN), di, di, $ );
  if t < 0 then
    errmsg( 1147 );
    reenter
  else
    udc(BHLN) = t
  endif;
endif;

PROC BH8
{ Check child's line number is not greater than max }
if $ > HH11 then
  errmsg( 1149 );
  reenter
{ If child is listed in HH }
elseif $ > 0 then
  { check for duplicates }
  do i = 1 while i < curocc()
    if BH8(i) = $ then
      errmsg( 1151 );
      reenter;
    endif;
  enddo;
  { Check mother's line number agrees with line number of mother in household questionnaire }
  if HL11($) <> notappl & HL12($) <> LN then
    if addmode then
      errmsg( 1150, HL12($), LN );
    endif
  endif;
  { Check sex of child against sex in household questionnaire }
  if BH3 <> HL4($) then
    if addmode then
      errmsg( 1141, HL4($), BH3 );
    endif;
  endif;
  { Check month of birth of child against month of birth in household questionnaire }
  if BH4M <> HL5M($) then
    if addmode then
      errmsg( 2829, HL5M($), BH4M );
    endif;
  endif;
  { Check year of birth of child against year of birth in household questionnaire }
  if BH4Y <> HL5Y($) then
    if addmode then
      errmsg( 2830, HL5Y($), BH4Y );
    endif;
  endif;
  { Check age of child against age in household questionnaire }
  if !special(BH6) & !special(HL6($)) then
    if !( (BH6-HL6($)) in (-2):2 ) then
      if addmode then
        errmsg( 1148, HL6($), BH6 );
      endif;
    endif
  endif;
endif;
skip to BH10;

PROC BH9U
{ check unit is for special answer, number must be a special answer,
  but special answers are allowed for number when unit is given }
if badspecial( BH9U, BH9N ) then
  errmsg( 1153 );
  reenter
endif;

{ Check maximum and mininum values }
box BH9U => maxd;
       1 => 30;       { 0-30 days   }
       2 => 23;       { 1-23 months }
       3 => 40;       { 2-40 years  }
         => 99;
endbox;
mind = BH9U-1;
if BH9U = 9 then mind = 0 endif;
if BH9U = 3 then mind = 2 endif; { Change to allow 1 year to be entered - checked in editing }
if !( $ in mind:maxd ) & addmode then
  errmsg( 1154, mind, maxd, BH9U )
endif;

{ Check age at death plausible considering date of birth }
box BH9U : $             => adeath;
         : missing, >=97 => 0;
       1 :               => int($/30);
       2 :               => $;
       3 :               => $*12;
         :               => 0;
endbox;
if ldc(BHLN) + adeath > di then
  if addmode then
    errmsg( 1155, ldc(BHLN), adeath, di )
  endif
elseif udc(BHLN) + adeath > di then
  udc(BHLN) = di - adeath
endif;

PROC BH10
preproc
if BHLN = 1 then
  skip to next BHLN
endif;

PROC DB1
if $ = 1 then
  endgroup
endif;

PROC DB2
if $ <> 1 then
  endgroup
endif;

PROC DB3N
if badspecial(DB3U,DB3N) then
  errmsg(9992);
  reenter
endif;

PROC MN1
if $ <> 1 then
  skip to MN5
endif;

PROC MN2
alphavar = $;
if alphachk("ABCFGX") then
  errmsg(9998);
  reenter
else
  $ = alphavar;
endif;

PROC MN6
if $ <> 1 then
  skip to MN9
endif;

PROC MN7
if $ >= 8 then
  skip to MN9
elseif $ >= 2 then
  skip to MN13
endif;

PROC MN9
if $ <> 1 then
  skip to MN13
endif;

PROC MN10
if $ >= 8 then
  skip to MN13
endif;

PROC MN11
if valid(MN11) and WB2-MN11 < minab/12 then
  errmsg(1201,minab/12);
endif;

PROC MN13
preproc
if MN1 <> 1 then
  skip to MN17
endif;

postproc
if $ <> 1 then
  skip to MN17
endif;

PROC MN14
alphavar = $;
if alphachk("ABXZ") then
  errmsg(9998);
  reenter
else
  $ = alphavar;
endif;
{ Check "Don't Know" is only response }
if pos("Z",$) & alphsize > 1 then
  errmsg(9996);
  reenter
endif;

{ MN15 Filter}
if pos("A",MN14) then
  { continue }
else
  skip to MN17
endif;

PROC MN17
alphavar = $;
if alphachk("ABCFGHXY") then
  errmsg(9998);
  reenter
else
  $ = alphavar;
endif;
{ Check "No one" is only response }
if pos("Y",$) & alphsize > 1 then
  errmsg(9995);
  reenter
endif;

PROC MN18
if $ in 11,12,96 then
  skip to MN20
endif;

PROC MN21
if $ <> 1 then
  skip to MN23
endif;

PROC MN22
{ Check special answers }
if (MN22A = 9 <=> MN22 < 9.997) then
  errmsg(1301);
  reenter
endif;

PROC MN24
if $ <> 1 then
  endgroup
endif;

PROC MN25N
recode MN25U  : MN25N       => err;
          0   : 0           => 0;   { Immediately }
          1   : 0-23,99     => 0;   { Hours }
          2   : 1-90,99     => 0;   { Days }
          9   : 98-99       => 0;   { DK, Missing }
              :             => 1;
endrecode;
if err then
  errmsg(9992);
  reenter;
endif;

PROC MN26
if MN26 <> 1 then
  endgroup
endif;

PROC MN27
alphavar = $;
if alphachk("ABCDEFGHIX") then
  errmsg(9998);
  reenter
else
  $ = alphavar;
endif;

PROC PN2U
preproc   {PN1 Filter}
		  {if child is not  delivered in a health facility skip to PN6}
if MN18 in 11:12 or MN18 >=96 then
    {PN6 Filter}
	if MN17A = "A" or MN17B = "B" or MN17C = "C" or MN17G = "G" then
		skip to PN7;
	else 
		skip to PN10;	
	endif;
endif;	
PROC PN5
if $ = 1 then
	skip to PN11
else skip PN16;
endif;
PROC PN7
{PN6 Filter}
if MN17A <> "A" and MN17B <> "B" and MN17C <> "C" and MN17G <> "G" then
		skip to PN10;	
endif;
PROC PN9
if $ = 1 then
	skip to PN11
else skip PN18;
endif;
PROC PN10
if $ <> 1 then
	skip to PN19;
endif;
PROC PN16
{PN15 Filter}
preproc  
if MN18 in 11:12 or MN18 >=96 then
    {PN17 Filter}
	if MN17A = "A" or MN17B = "B" or MN17C = "C" or MN17G = "G" then
		skip to PN18;
	else 
		skip to PN19;	
	endif;
endif;	

postproc
if $ = 1 then
	skip to PN20;
else endgroup;
endif;	
PROC PN18
if $ = 1 then
	skip to PN20;
else endgroup;
endif;	
PROC PN19
if $ = 1 then
	endgroup;
endif;	
PROC IS2
preproc
if count (FORMHL_ROSTER where HL9 = WM4) = 0 then
  endgroup
endif;

postproc
alphavar = $;
if alphachk("ABCDEFGXYZ") then
  errmsg(9998);
  reenter
else
  $ = alphavar;
endif;

PROC CP1
if $ = 1 then
  endgroup
endif;

PROC CP2
if $ <> 1 then
  endgroup
endif;

PROC CP3
alphavar = $;
if alphachk("ABCDEFGHIJKLMX") then
  errmsg(9998);
  reenter
else
  $ = alphavar;
endif;

PROC UN2
preproc
if CP1 <> 1 then
  skip to UN6
endif;

postproc
if $ = 1 then
  skip to UN4
endif;

PROC UN4
if $ = 1 then
  skip to UN7U;
else
  skip to UN13U;
endif;

PROC UN6
preproc
if pos("A",CP3) then
  skip to UN13U
endif;

postproc
if UN6 in 2, 8, 9 then
	skip to UN10;
endif;

if UN6 = 3 then
	skip to UN11;
endif
PROC UN7N
if badspecial(UN7U,UN7N) then
  errmsg(9992);
  reenter
endif;
if $ = 94 then
  skip to UN11
endif;

PROC UN10
preproc
if CP2 = 1 then
  skip to UN13U
endif;

postproc
if $ <> 2 then
  skip to UN13U
endif;

PROC UN11
alphavar = $;
if alphachk("ABCDEFGHIXZ") then
  errmsg(9998);
  reenter
else
  $ = alphavar;
endif;
{ Check "Don't Know" is only response }
if pos("Z",$) & alphsize > 1 then
  errmsg(9996);
  reenter
endif;

if pos("C",$) then
  endgroup
endif;

PROC UN13N
if badspecial(UN13U,UN13N) then
  errmsg(9992);
  reenter
endif;

PROC FG1
if $ = 1 then
  skip to FG3
endif;

PROC FG2
if $ <> 1 then
  skip to DV1A
endif;

PROC FG3
if $ <> 1 then
  skip to FG9
endif;

PROC FG4
if $ = 1 then
  skip to FG6
endif;

PROC FG9
{ Count up total number of living daughters}
x = NAtoZero(CM5B)+NAtoZero(CM7B);

if x <> $ then 
	errmsg (1602,$,x);
	reenter;
endif;	
PROC FORMFC_ROSTER
preproc
if FG9 = 0 then
  skip to FG22;
endif;
PROC FGLN
preproc
if curocc(FORMFC_ROSTER) > FG9 then
  endgroup
endif;

if inEntry then
  do i = 1 while i <= FG9
    if i <= FG9 then
      FGLN(i) = i;
    else
      FGLN(i) = notappl;
    endif;
  enddo;
endif;
PROC FG13
if valid(FG13) and FG13 + (minab/12) > WB2 then
  {+EN} errmsg(1601,WB2,minab/12,"age", FG16) {EN+}
  {{FR} errmsg(1601,WB2,minab/12,"ge", FG16); {FR}}
endif;

PROC FG15
preproc
if FG13 >= 15 then skip to next FGLN
endif;

postproc
if $ <> 1 then skip to next FGLN
endif;
PROC FG16
if valid(FG16) and FG16 + (minab/12) > WB2 then
  {+EN} errmsg(1601,WB2,minab/12,"age at circumsision", FG16) {EN+}
  {{FR} errmsg(1601,WB2,minab/12,"ge l'excision", FG16); {FR}}
endif;

if FG16 < 98 and FG16 >= FG13 then 
	{+EN} errmsg ("Age at circumsision higher than age"); {EN+}
	{{FR} errmsg ("Age l'excision plus grand que age"); {FR}}
	reenter;
endif;	
	
PROC FG17
if $ = 1 then skip to FG19;
endif;
PROC FG20
skip to next FGLN;
PROC MA1
if $ = 3 then
  skip to MA5
endif;

PROC MA3
if $ <> 1 then
  skip to MA7
endif;

PROC MA4
skip to MA7;

PROC MA5
if $ = 3 then
  endgroup
endif;

PROC MA8Y
{ Check woman at least 4 when married (minam=min. age at marriage) }
if MA8Y < 9996 and WB1Y < 9996 then
  if valid(MA8M) and valid(WB1M) then
    if cmcode(MA8M,MA8Y) - cmcode(WB1M,WB1Y) < 0 then
      errmsg(1401,WB1M,WB1Y,MA8M,MA8Y,0);
    elseif cmcode(MA8M,MA8Y) - cmcode(WB1M,WB1Y) < minam then
      errmsg(1401,WB1M,WB1Y,MA8M,MA8Y,minam/12);
    endif;
  else
    if MA8Y - WB1Y < 0 then
      errmsg(1401,WB1M,WB1Y,MA8M,MA8Y,0);
    elseif MA8Y - WB1Y < int(minam/12)-1 then
      errmsg(1401,WB1M,WB1Y,MA8M,MA8Y,minam/12);
    endif;
  endif;
endif;

if MA8Y < 9997 {and MA8M < 97} then
  endgroup
endif;

PROC MA9
if $ > WB2 then
  errmsg(1701,$,WB2);
  reenter;
endif;

PROC SB1
if $ in WB2+1:49 then
  errmsg(1801,SB1,WB2);
  reenter
endif;
if $ = 0 then
  endgroup
endif;

PROC SB3N
if badspecial(SB3U,SB3N) or
	(SB3U = 3 & SB3N in 12:98) or
	(SB3U = 2 & SB3N in 52:98) then
  errmsg(9992);
  reenter
endif;
{ Compare maximum age at last sex to SB1}
{ NOTE: Check will require action in the editing program;
  here the DE operator just checks the values entered }
if SB1 < 95 & SB3U = 4 & WB2-SB3N < SB1 then
  errmsg(1802,WB2-SB3N,SB1);
endif;
{ NOTE: could be combined with above; separate for clarity }
if SB3U = 4 then
  skip to SB15
endif;

PROC SB5
if $ <> 1 and $ <> 2 then
  skip to SB7
endif;

PROC SB7
{Filter SB6}
preproc
if MA1 = 1 or MA1 = 2 then skip to SB8;
endif;

PROC SB8
if $ <> 1 then skip to SB15;
endif;
PROC SB9

PROC SB10

PROC SB12
{Filter SB11}
preproc
if (MA1 = 1 or MA1 = 2) and MA7 = 1 then skip to SB13;
endif;
PROC SB13
if $ <> 1 then skip to SB15;
endif;




PROC SB15
if $ < SB14 then
  errmsg (1803,$,SB14);
  reenter;
endif;
PROC FORMHA
if endmess() then
  reenter WM11M
endif;
endlevel;

PROC HA1
if $ <> 1 then
  skip to WM11H
endif;

PROC HA15A
preproc
{ HA13 Filter }
if CM13 <> "Y" then
  skip to HA24;
endif;

{ HA14 Filter }
if MN1 <> 1 then
  skip to HA24
endif;

PROC HA16
if $ <> 1 then
  skip to HA20
endif;

PROC HA17
if $ <> 1 then
  skip to HA22
endif;

PROC HA18
skip to HA22;

PROC HA20
preproc
if !poschar("ABC",MN17) then
  skip to HA24
endif;

postproc
if $ <> 1 then
  skip to HA24
endif;

PROC HA22
if $ = 1 then
  skip to HA25
endif;

PROC HA23
skip to WM11H;

PROC HA24
if $ <> 1 then
  skip to HA27
endif;

PROC HA26
skip to WM11H;

PROC WM11H
if !inentry and WM7 <> 1
	then endgroup;
endif;
PROC WM11M
if Valid(WM10H) and Valid(WM10M) and Valid(WM11H) and Valid(WM11M) then
  if (WM10H*60+WM10M)>(WM11H*60+WM11M)then
  	errmsg(9990);
  	reenter
  endif;
endif;

PROC MM1
{MM2 Filter}
if $ < 2 then
	endgroup;
endif;	
PROC MMLN
preproc
if curocc(FORMMM_ROSTER) > MM1 then
  endgroup
endif;

if inEntry then
  do i = 1 while i <= MM1
    if i <= MM1 then
      MMLN(i) = i;
    else
      MMLN(i) = notappl;
    endif;
  enddo;
endif;
PROC MM6
if $ = 2 then
	skip to MM8
endif;

if $ in 8:9 then 
	skip to next MMLN
endif; 

PROC MM7
skip to next MMLN;
PROC MM9
if MM5 = 1 or $ < 12 then
	skip to next MMLN;
endif;
PROC MM10
if $ = 1 then
	skip to MM13;
endif;
PROC MM11
if $ = 1 then
	skip to MM13;
endif;
PROC TA1
if $ <> 1 then 
	skip to TA6;
endif;
PROC TA2
if $ = 0 then
	skip to TA6
endif;	
PROC TA3
if $ <> 1 then
	skip to TA6;
endif;	
PROC TA6
if $ <> 1 then
	skip to TA10;
endif;	
PROC TA7
if $ <> 1 then
	skip to TA10;
endif;	
PROC TA8
alphavar = $;
if alphachk("ABCDX") then
  errmsg(9998);
  reenter
else
  $ = alphavar;
endif;
PROC TA10
if $ <> 1 then
	skip to TA14;
endif;	
PROC TA11
if $ <> 1 then
	skip to TA14;
endif;	
PROC TA12
alphavar = $;
if alphachk("ABCX") then
  errmsg(9998);
  reenter
else
  $ = alphavar;
endif;
PROC TA14
if $ <> 1 then 
	endgroup;
endif;	
PROC TA15
if $ = 0 then 
	endgroup;
endif;
PROC TA16
if $ = 0 then 
	endgroup;
endif;
PROC LS5
if $ <> 1 then 
	skip to LS7;
endif;	
PROC MWM1
preproc
MWM1 = HH1;
MWM2 = HH2;
PROC MWM4
preproc
if addmode then
  display(concat( {+EN} "Questionnaire for Man ", {EN+}
                  {{FR} "Questionnaire pour la Homme ", {FR}}
                  {{ES} "ES", {ES}}
                  edit("99", LN)));
endif;

postproc
if MWM4 <> LN then
  errmsg(3000, LN);
  reenter
endif;
PROC MWM6Y
recode MWM6Y :     MWM6M       : MWM6D => err;
   2009-2012 : 1,3,5,7,8,10,12 : 1-31  => 0;
   2009-2012 : 4,6,9,11        : 1-30  => 0;
   2009-2011 : 2               : 1-28  => 0;
  		2012 : 2               : 1-29  => 0;
             :                 :       => 1;
endrecode;
if err then
  errmsg(0017, {+EN} "Problem with Day/Month/Year combination"); {EN+}
               {{FR} "Problme avec la combinaison du Jour/Mois/Anne"); {FR}}
               {{ES} "ES"); {ES}}
  reenter
endif;
dd = (HH5Y*100 + HH5M)*100 + HH5D;
ddm= (MWM6Y*100 + MWM6M)*100 + MWM6D;
ss = sysdate("yyyymmdd");
if ddm >= ss or ddm < dd then
  errmsg(0017, {+EN} "Date of interview either after current date or before minimum date of interview"); {EN+}
               {{FR} "Date de l'interview est ou aprs la date actuelle ou avant la date minimum de l'interview"); {FR}}
               {{ES} "ES"); {ES}}
  reenter
endif;
dimn = cmcode(MWM6M,MWM6Y);
PROC MWM9
preproc
if addmode & special(visualvalue($)) & opid <> notappl then
  $ = opid;
endif;
PROC MWM10H
preproc
if !inentry and MWM7 <> 1
	then endgroup;
endif;
PROC MWB1M
if $ <> HL5M(LN) then
  errmsg(3004,MWB1M,HL5M(LN));
endif;
PROC MWB1Y
if $ <> HL5Y(LN) then
  errmsg(3005,MWB1Y,HL5Y(LN));
endif;
udob = dimn - mminage*12;
ldob = dimn - mmaxage*12 - 11;
if MWB1Y < 9997 then
  ldob = setlb(MWB1M,MWB1Y,0);
  udob = setub(MWB1M,MWB1Y,9999);
  if udob < dimn - mmaxage*12 - 11 or ldob > dimn - mminage*12 then
    errmsg(3001);
  { reenter }
  endif;
endif;
PROC MWB2
if $ <> HL6(LN) then
  errmsg(3002,MWB2,HL6(LN));
endif;
{ Lower bound of CMC date of birth }
t = adjlba(ldob,udob,dimn,dimn,MWB2);
if t < 0 then
  errmsg(3003);
{ reenter }
else
  ldob = t
endif;
{ Upper bound of CMC date of birth }
t = adjuba(ldob,udob,dimn,dimn,MWB2);
if t < 0 then
  errmsg(3003);
{ reenter }
else
  udob = t
endif;
PROC MWB3
if $ <> ED3(LN) and ED4A(LN) <> 0 then
  errmsg(3011,ED3(LN),MWB3);
endif;
if $ <> 1 then
  skip to MWB7
endif;
PROC MWB4
if $ <> ED4A(LN) then
  errmsg(3012,ED4A(LN),MWB4);
endif;

if $ = 0 then
  skip to MWB7
endif;
PROC MWB5
if $ <> ED4B(LN) then
  errmsg(3013,ED4B(LN),MWB5);
endif;
recode MWB4 : $           => err; { Fix maximum grade for each possible level }
            : 97,98,99    => 0;   { Inconsistent, missing, DK grade }
          1 : 0-8         => 0;   { Primary }
          2 : 0-4         => 0;   { Secondary }
          3 : 0-6         => 0;   { Higher }
          8 :             => 0;   { DK level }
          9 :             => 0;   { Missing level }
            :             => 1;
endrecode;
if err then
  errmsg(3014);
  { reenter }
endif;
{ MWB6 Filter }
if MWB4 in 2,3 then
  endgroup
endif;


PROC MMT2
preproc
if MWB7 = 1 or MWB7 = 5 then
	skip to MMT3;
endif;
PROC MMT6
preproc
if MWB2 in 25:49 then
	endgroup;
endif;	

postproc
if $ <> 1 then
	skip to MMT9;
endif;	
PROC MMT7
if $ <> 1 then
	skip to MMT9;
endif;	
PROC MMT9
if $ <> 1 then
	endgroup;
endif;	
PROC MMT10
if $ <> 1 then
	endgroup;
endif;	
PROC MCM1
if $ <> 1 then
  skip to MCM8
endif;
PROC MCM3
if MWB2 - MCM3 < (minab/12) then
  errmsg(3103,minab/12);
endif;
PROC MCM4
if $ <> 1 then
  skip to MCM6
endif;
PROC MCM5B
{ Check for at least one child living at home - otherwise MCM3 must be 2 }
if MCM5A = 0 and MCM5B = 0 then
  errmsg(3110, "MCM4");
  reenter
endif;
PROC MCM6
if $ <> 1 then
  skip to MCM8
endif;
PROC MCM7B
{ Check for at least one child living away - otherwise MCM6 must be 2 }
if MCM7A = 0 and MCM7B = 0 then
  errmsg(3110, "MCM6");
  reenter
endif;
PROC MCM8
if $ <> 1 then
  skip to MCM10
endif;
PROC MCM9B
{ Check for at least one child who died - otherwise MCM8 must be 2 }
if MCM9A = 0 and MCM9B = 0 then
  errmsg(3110, "MCM8");
  reenter
endif;
PROC MCM10
{ Count up total children ever born }
x = NAtoZero(MCM5A)+NAtoZero(MCM5B)+
    NAtoZero(MCM7A)+NAtoZero(MCM7B)+
    NAtoZero(MCM9A)+NAtoZero(MCM9B);
{ Check count of children ever born with total }
if x <> MCM10 then
  errmsg(3111, MCM10, x);
  reenter;
endif;

if $ = 0 then
  endgroup;
endif;
PROC MCM11A
if $ <> 2 then
  skip to MCM12D
endif;
PROC MCM12Y
ldoblc = ldobfc;
udoblc = dimn;
if MCM12Y < 9997 then
  ldoblc = setlb(MCM12M,MCM12Y,0);
  udoblc = setub(MCM12M,MCM12Y,9999);
  if udoblc < ldob + mminab then
    errmsg(3121,int(mminab/12));
  elseif ldoblc > dimn then
    errmsg(3122);
  endif;
endif;



PROC MMA1
if $ = 3 then
  skip to MMA5
endif;
PROC MMA3
if $ <> 1 then
  skip to MMA7
endif;
PROC MMA4
skip to MMA7;
PROC MMA7
if $ = 3 then
  endgroup
endif;
PROC MMA8Y
{ Check man at least 4 when married (minam=min. age at marriage) }
if MMA8Y < 9996 and MWB1Y < 9996 then
  if valid(MMA8M) and valid(MWB1M) then
    if cmcode(MMA8M,MMA8Y) - cmcode(MWB1M,MWB1Y) < 0 then
      errmsg(3401,MWB1M,MWB1Y,MMA8M,MMA8Y,0);
    elseif cmcode(MMA8M,MMA8Y) - cmcode(MWB1M,MWB1Y) < minam then
      errmsg(3401,MWB1M,MWB1Y,MMA8M,MMA8Y,minam/12);
    endif;
  else
    if MMA8Y - MWB1Y < 0 then
      errmsg(3401,MWB1M,MWB1Y,MMA8M,MMA8Y,0);
    elseif MMA8Y - MWB1Y < int(minam/12)-1 then
      errmsg(3401,MWB1M,MWB1Y,MMA8M,MMA8Y,minam/12);
    endif;
  endif;
endif;

if MMA8Y < 9997 {and MMA8M < 97} then
  endgroup
endif;
PROC MMA9
if $ > MWB2 then
  errmsg(3701,$,MWB2);
  reenter;
endif;
PROC MSB1
if $ in MWB2+1:49 then
  errmsg(3801,MSB1,MWB2);
  reenter
endif;
if $ = 0 then
  endgroup
endif;
PROC MSB3N
if badspecial(MSB3U,MSB3N) or
	(MSB3U = 3 & MSB3N in 12:98) or
	(MSB3U = 2 & MSB3N in 52:98) then
  errmsg(9992);
  reenter
endif;
{ Compare maximum age at last sex to SB1}
{ NOTE: Check will require action in the editing program;
  here the DE operator just checks the values entered }
if MSB1 < 95 & MSB3U = 4 & MWB2-MSB3N < MSB1 then
  errmsg(3802,MWB2-MSB3N,MSB1);
endif;
{ NOTE: could be combined with above; separate for clarity }
if MSB3U = 4 then
  skip to MSB15
endif;
PROC MSB5
if $ <> 1 and $ <> 2 then
  skip to MSB7
endif;
PROC MSB7
{Filter MSB6}
preproc
if MMA1 = 1 or MMA1 = 2 then skip to MSB8;
endif;
PROC MSB8
if $ <> 1 then skip to MSB15;
endif;
PROC MSB12
{Filter MSB11}
preproc
if (MMA1 = 1 or MMA1 = 2) and MMA7 = 1 then skip to MSB13;
endif;

PROC MSB13
if $ <> 1 then skip to MSB15;
endif;
PROC MSB15
if $ < MSB14 then
  errmsg (3803,$,MSB14);
  reenter;
endif;
PROC MHA1
if $ <> 1 then
  endgroup
endif;
PROC MHA24
if $ <> 1 then
  skip to MHA27
endif;
PROC MHA26
endgroup;
PROC MMC1
if $ <> 1 then
  endgroup
endif;

PROC MMC2
if $ in MWB2+1:49 then
  errmsg(3901,MMC1,MWB2);
  reenter
endif;
PROC MTA1
if $ <> 1 then
  skip to MTA6;
endif;
PROC MTA2
if $ =0 then
  skip to MTA6;
endif;
PROC MTA3
if $ <> 1 then
  skip to MTA6;
endif;
PROC MTA6
if $ <> 1 then
  skip to MTA10;
endif;
PROC MTA7
if $ <> 1 then
  skip to MTA10;
endif;
PROC MTA8
alphavar = $;
if alphachk("ABCDX") then
  errmsg(9998);
  reenter
else
  $ = alphavar;
endif;
PROC MTA10
if $ <> 1 then
  skip to MTA14;
endif;
PROC MTA11
if $ <> 1 then
  skip to MTA14;
endif;
PROC MTA12
alphavar = $;
if alphachk("ABCX") then
  errmsg(9998);
  reenter
else
  $ = alphavar;
endif;
PROC MTA14
if $ <> 1 then
  endgroup
endif;
PROC MTA15
if $ = 0 then
 endgroup;
endif;
PROC MTA16
if $ = 0 then
 endgroup;
endif;
PROC FORMMLS
if endmess() then
  reenter MWM11H
endif;
 endlevel;
PROC MLS2
if MWB2 in 25:49 then
 skip to MWM11H;
endif;
PROC MLS5
if $ <> 1 then
  skip to MLS7
endif;
PROC MWM11H
preproc
if !inentry and mwm7 <> 1
	then endgroup;
endif;
PROC MWM11M
if Valid(MWM10H) and Valid(MWM10M) and Valid(MWM11H) and Valid(MWM11M) then
  if (MWM10H*60+MWM10M)>(MWM11H*60+MWM11M)then
  	errmsg(9990);
  	reenter
  endif;
endif;
PROC FORMCH
if UF9 <> 1 then
  if endmess() then
    reenter UF11
  endif;
  endlevel
endif;

PROC UF1
preproc
UF1 = HH1;
UF2 = HH2;

PROC UF4
preproc
if addmode then
  display(concat( {+EN} "Questionnaire for Child ", {EN+}
                  {{FR} "Questionnaire pour les Enfants ", {FR}}
                  {{ES} "ES", {ES}}
                  edit("99", LN)));
endif;

postproc
if UF4 <> LN then
  errmsg(2000,LN);
  reenter
endif;

PROC UF6
if HL9(LN) <> UF6 then
  errmsg(2004,UF6,HL9(LN));
  { Critical var; enforce consistency during editing }
  reenter;
endif;

PROC UF8Y
recode  UF8Y  :     UF8M        : UF8D => err;
    2009-2012 : 1,3,5,7,8,10,12 : 1-31 => 0;
    2009-2012 : 4,6,9,11        : 1-30 => 0;
    2009-2011 : 2               : 1-28 => 0;
         2012 : 2               : 1-29 => 0;
              :                 :      => 1;
endrecode;
if err then
  errmsg(0017, {+EN} "Problem with Day/Month/Year combination"); {EN+}
               {{FR} "Problme avec la combinaison du Jour/Mois/Anne"); {FR}}
               {{ES} "ES"); {ES}}
  reenter
endif;
dd = (HH5Y*100 + HH5M)*100 + HH5D;
ddw= (UF8Y*100 + UF8M)*100 + UF8D;
ss = sysdate("yyyymmdd");
if ddw >= ss or ddw < dd then
  errmsg(0017, {+EN} "Date of interview either after current date or before minimum date of interview"); {EN+}
               {{FR} "Date de l'interview est ou aprs la date actuelle ou avant la date minimum de l'interview"); {FR}}
               {{ES} "ES"); {ES}}
  reenter
endif;
dich = cmcode(UF8M,UF8Y);

PROC UF11
preproc
if addmode & special(visualvalue($)) & opid <> notappl then
  $ = opid;
endif;
PROC UF12H
preproc
if !inentry and UF9 <> 1
	then endgroup;
endif;
PROC AG1M
if AG1M <> HL5M(LN) then
  errmsg(2005,AG1M,HL5M(LN));
endif;
PROC AG1Y
udob = dich;
ldob = dich - chhlth*12 - 11;
if AG1Y < 9997 then
  ldob = setlb(AG1M,AG1Y,0);
  udob = setub(AG1M,AG1Y,9999);
  if udob < dich - chhlth*12 - 11 or ldob > dich then
    errmsg(2001);
  { reenter }
  endif;
endif;

if AG1Y <> HL5Y(LN) then
  errmsg(2006,AG1Y,HL5Y(LN));
endif;

PROC AG2
if AG2 <> HL6(LN) then
  errmsg(2002,AG2,HL6(LN));
endif;
{ Lower bound of CMC date of birth }
t = adjlba(ldob,udob,dich,dich,AG2);
if t < 0 then
  errmsg(2003);
  reenter
else
  ldob = t
endif;
{ Upper bound of CMC date of birth }
t = adjuba(ldob,udob,dich,dich,AG2);
if t < 0 then
  errmsg(2003);
  reenter
else
  udob = t
endif;

PROC BR1
if $ in 1,2 then
  endgroup
endif;

PROC BR2
if $ = 1 then
  endgroup
endif;

PROC EC5
preproc
if AG2 < 3 then
  endgroup;
endif;

postproc
if $ <> 1 then
  skip to EC7A
endif;

PROC EC7A
alphavar = $;
if alphachk("ABXY") then
  errmsg(9998);
  reenter
else
  $ = alphavar;
endif;
{ Check "No one" is only response }
if pos("Y",$) & alphsize > 1 then
  errmsg(9995);
  reenter
endif;

PROC EC7B
alphavar = $;
if alphachk("ABXY") then
  errmsg(9998);
  reenter
else
  $ = alphavar;
endif;
{ Check "No one" is only response }
if pos("Y",$) & alphsize > 1 then
  errmsg(9995);
  reenter
endif;

PROC EC7C
alphavar = $;
if alphachk("ABXY") then
  errmsg(9998);
  reenter
else
  $ = alphavar;
endif;
{ Check "No one" is only response }
if pos("Y",$) & alphsize > 1 then
  errmsg(9995);
  reenter
endif;

PROC EC7D
alphavar = $;
if alphachk("ABXY") then
  errmsg(9998);
  reenter
else
  $ = alphavar;
endif;
{ Check "No one" is only response }
if pos("Y",$) & alphsize > 1 then
  errmsg(9995);
  reenter
endif;

PROC EC7E
alphavar = $;
if alphachk("ABXY") then
  errmsg(9998);
  reenter
else
  $ = alphavar;
endif;
{ Check "No one" is only response }
if pos("Y",$) & alphsize > 1 then
  errmsg(9995);
  reenter
endif;

PROC EC7F
alphavar = $;
if alphachk("ABXY") then
  errmsg(9998);
  reenter
else
  $ = alphavar;
endif;
{ Check "No one" is only response }
if pos("Y",$) & alphsize > 1 then
  errmsg(9995);
  reenter
endif;

PROC BF1
if $ <> 1 then
  skip to BF3
endif;

PROC BF4
if $ <> 1 then
  skip to BF6
endif;

PROC BF6
if $ <> 1 then
  skip to BF8
endif;

PROC BF13
if $ <> 1 then
  skip to BF15
endif;

PROC BF16
if $ <> 1 then
  skip to BF18
endif;

PROC CA1
if $ <> 1 then
  skip to CA7
endif;

PROC CA5
if $ <> 1 then
  skip to CA7
endif;

PROC CA6
alphavar = $;
if alphachk("ABCGHLMNOQX") then
  errmsg(9998);
  reenter
else
  $ = alphavar;
endif;

PROC CA7
if $ <> 1 then
  skip to CA15
endif;

PROC CA8
if $ <> 1 then
  skip to CA15
endif;

PROC CA9
if $ in 2,6 then
  skip to CA15
endif;

PROC CA10
if $ <> 1 then
  skip to CA12
endif;

PROC CA11
alphavar = $;
if alphachk("ABCDEHIJKLOPQRX") then
  errmsg(9998);
  reenter
else
  $ = alphavar;
endif;

PROC CA12
if $ <> 1 then
  skip to CA15
endif;

PROC CA13
alphavar = $;
if alphachk("ABMPQRXZ") then
  errmsg(9998);
  reenter
else
  $ = alphavar;
endif;
{ Check "No one" is only response }
if pos("Z",$) & alphsize > 1 then
  errmsg(9996);
  reenter
endif;

PROC CA15
preproc
{CA14 filter}
if AG2 >= 3 then
  endgroup;
endif;

PROC ML1
if $ <> 1 then
  endgroup
endif;

PROC ML3
if $ <> 1 then
  skip to ML8
endif;

PROC ML4
if $ <> 1 then
  skip to ML8
endif;

PROC ML5
if $ <> 1 then
  skip to ML7
endif;

PROC ML6
alphavar = $;
if alphachk("ABCDEFHIJPQRXZ") then
  errmsg(9998);
  reenter
else
  $ = alphavar;
endif;
{ Check "Don't Know" is only response }
if pos("Z",$) & alphsize > 1 then
  errmsg(9996);
  reenter
endif;

PROC ML7
if ML7 = 1 then
  skip to ML9
else
  skip to ML11
endif;

PROC ML8
if ML8 <> 1 then
  skip to ML11
endif;

PROC ML9
alphavar = $;
if alphachk("ABCDEFHIJPQRXZ") then
  errmsg(9998);
  reenter
else
  $ = alphavar;
endif;
{ Check "Don't Know" is only response }
if pos("Z",$) & alphsize > 1 then
  errmsg(9996);
  reenter
endif;

PROC ML11
preproc
{ ML10 Filter }
if not (poschar("ABCDEFH",ML6) or poschar("ABCDEFH",ML9)) then
  endgroup
endif;

PROC IM1
if $ = 1 then
  skip to IM3BD;
elseif $ = 2 then
  skip to IM6;
endif;

PROC IM2
skip to IM6;

PROC IM3BD
if $ in 0,44,66 then
  skip to IM3P0D;
endif;

PROC IM3BY
if vdvalid(IM3BD,IM3BM,IM3BY) then
  errmsg(2701, {+EN} "BCG", {EN+}
               {{FR} "BCG", {FR}}
               {{ES} "ES", {ES}}
               IM3BD,IM3BM,IM3BY);
elseif vdoi(IM3BD,IM3BM,IM3BY) then
  errmsg(2702, {+EN} "BCG", {EN+}
               {{FR} "BCG", {FR}}
               {{ES} "ES", {ES}}
               IM3BD,IM3BM,IM3BY,UF8D,UF8M,UF8Y);
elseif vdob(IM3BD,IM3BM,IM3BY) then
  errmsg(2703, {+EN} "BCG", {EN+}
               {{FR} "BCG", {FR}}
               {{ES} "ES", {ES}}
               IM3BD,IM3BM,IM3BY,AG1D,AG1M,AG1Y);
endif;

PROC IM3P0D
if $ in 0,44,66 then
  skip to IM3P1D;
endif;

PROC IM3P0Y
if vdvalid(IM3P0D,IM3P0M,IM3P0Y) then
  errmsg(2701, {+EN} "Polio at birth", {EN+}
               {{FR} "VPO 0", {FR}}
               {{ES} "ES", {ES}}
               IM3P0D,IM3P0M,IM3P0Y);
elseif vdoi(IM3P0D,IM3P0M,IM3P0Y) then
  errmsg(2702, {+EN} "Polio at birth", {EN+}
               {{FR} "VPO 0", {FR}}
               {{ES} "ES", {ES}}
               IM3P0D,IM3P0M,IM3P0Y,UF8D,UF8M,UF8Y);
elseif vdob(IM3P0D,IM3P0M,IM3P0Y) then
  errmsg(2703, {+EN} "Polio at birth", {EN+}
               {{FR} "VPO 0", {FR}}
               {{ES} "ES", {ES}}
               IM3P0D,IM3P0M,IM3P0Y,AG1D,AG1M,AG1Y);
endif;

PROC IM3P1D
if $ in 0,44,66 then
  skip to IM3P2D;
endif;

PROC IM3P1Y
if vdvalid(IM3P1D,IM3P1M,IM3P1Y) then
  errmsg(2701, {+EN} "Polio 1", {EN+}
               {{FR} "VPO 1", {FR}}
               {{ES} "ES", {ES}}
               IM3P1D,IM3P1M,IM3P1Y);
elseif vdoi(IM3P1D,IM3P1M,IM3P1Y) then
  errmsg(2702, {+EN} "Polio 1", {EN+}
               {{FR} "VPO 1", {FR}}
               {{ES} "ES", {ES}}
               IM3P1D,IM3P1M,IM3P1Y,UF8D,UF8M,UF8Y);
elseif vdob(IM3P1D,IM3P1M,IM3P1Y) then
  errmsg(2703, {+EN} "Polio 1", {EN+}
               {{FR} "VPO 1", {FR}}
               {{ES} "ES", {ES}}
               IM3P1D,IM3P1M,IM3P1Y,AG1D,AG1M,AG1Y);
endif;

PROC IM3P2D
if $ in 0,44,66 then
  skip to IM3P3D;
endif;

PROC IM3P2Y
if vdvalid(IM3P2D,IM3P2M,IM3P2Y) then
  errmsg(2701, {+EN} "Polio 2", {EN+}
               {{FR} "VPO 2", {FR}}
               {{ES} "ES", {ES}}
               IM3P2D,IM3P2M,IM3P2Y);
elseif vdoi(IM3P2D,IM3P2M,IM3P2Y) then
  errmsg(2702, {+EN} "Polio 2", {EN+}
               {{FR} "VPO 2", {FR}}
               {{ES} "ES", {ES}}
               IM3P2D,IM3P2M,IM3P2Y,UF8D,UF8M,UF8Y);
elseif vdob(IM3P2D,IM3P2M,IM3P2Y) then
  errmsg(2703, {+EN} "Polio 2", {EN+}
               {{FR} "VPO 2", {FR}}
               {{ES} "ES", {ES}}
               IM3P2D,IM3P2M,IM3P2Y,AG1D,AG1M,AG1Y);
endif;

PROC IM3P3D
if $ in 0,44,66 then
  skip to IM3D1D;
endif;

PROC IM3P3Y
if vdvalid(IM3P3D,IM3P3M,IM3P3Y) then
  errmsg(2701, {+EN} "Polio 3", {EN+}
               {{FR} "VPO 3", {FR}}
               {{ES} "ES", {ES}}
               IM3P3D,IM3P3M,IM3P3Y);
elseif vdoi(IM3P3D,IM3P3M,IM3P3Y) then
  errmsg(2702, {+EN} "Polio 3", {EN+}
               {{FR} "VPO 3", {FR}}
               {{ES} "ES", {ES}}
               IM3P3D,IM3P3M,IM3P3Y,UF8D,UF8M,UF8Y);
elseif vdob(IM3P3D,IM3P3M,IM3P3Y) then
  errmsg(2703, {+EN} "Polio 3", {EN+}
               {{FR} "VPO 3", {FR}}
               {{ES} "ES", {ES}}
               IM3P3D,IM3P3M,IM3P3Y,AG1D,AG1M,AG1Y);
endif;

PROC IM3D1D
if $ in 0,44,66 then
  skip to IM3D2D;
endif;

PROC IM3D1Y
if vdvalid(IM3D1D,IM3D1M,IM3D1Y) then
  errmsg(2701, {+EN} "DPT1", {EN+}
               {{FR} "DTCoq 1", {FR}}
               {{ES} "ES", {ES}}
               IM3D1D,IM3D1M,IM3D1Y);
elseif vdoi(IM3D1D,IM3D1M,IM3D1Y) then
  errmsg(2702, {+EN} "DPT1", {EN+}
               {{FR} "DTCoq 1", {FR}}
               {{ES} "ES", {ES}}
               IM3D1D,IM3D1M,IM3D1Y,UF8D,UF8M,UF8Y);
elseif vdob(IM3D1D,IM3D1M,IM3D1Y) then
  errmsg(2703, {+EN} "DPT1", {EN+}
               {{FR} "DTCoq 1", {FR}}
               {{ES} "ES", {ES}}
               IM3D1D,IM3D1M,IM3D1Y,AG1D,AG1M,AG1Y);
endif;

PROC IM3D2D
if $ in 0,44,66 then
  skip to IM3D3D;
endif;

PROC IM3D2Y
if vdvalid(IM3D2D,IM3D2M,IM3D2Y) then
  errmsg(2701, {+EN} "DPT2", {EN+}
               {{FR} "DTCoq 2", {FR}}
               {{ES} "ES", {ES}}
               IM3D2D,IM3D2M,IM3D2Y);
elseif vdoi(IM3D2D,IM3D2M,IM3D2Y) then
  errmsg(2702, {+EN} "DPT2", {EN+}
               {{FR} "DTCoq 2", {FR}}
               {{ES} "ES", {ES}}
               IM3D2D,IM3D2M,IM3D2Y,UF8D,UF8M,UF8Y);
elseif vdob(IM3D2D,IM3D2M,IM3D2Y) then
  errmsg(2703, {+EN} "DPT2", {EN+}
               {{FR} "DTCoq 2", {FR}}
               {{ES} "ES", {ES}}
               IM3D2D,IM3D2M,IM3D2Y,AG1D,AG1M,AG1Y);
endif;

PROC IM3D3D
if $ in 0,44,66 then
  skip to IM3H0D;
endif;

PROC IM3D3Y
if vdvalid(IM3D3D,IM3D3M,IM3D3Y) then
  errmsg(2701, {+EN} "DPT3", {EN+}
               {{FR} "DTCoq 3", {FR}}
               {{ES} "ES", {ES}}
               IM3D3D,IM3D3M,IM3D3Y);
elseif vdoi(IM3D3D,IM3D3M,IM3D3Y) then
  errmsg(2702, {+EN} "DPT3", {EN+}
               {{FR} "DTCoq 3", {FR}}
               {{ES} "ES", {ES}}
               IM3D3D,IM3D3M,IM3D3Y,UF8D,UF8M,UF8Y);
elseif vdob(IM3D3D,IM3D3M,IM3D3Y) then
  errmsg(2703, {+EN} "DPT3", {EN+}
               {{FR} "DTCoq 3", {FR}}
               {{ES} "ES", {ES}}
               IM3D3D,IM3D3M,IM3D3Y,AG1D,AG1M,AG1Y);
endif;

PROC IM3H0D
if $ in 0,44,66 then
  skip to IM3H1D;
endif;

PROC IM3H0Y
if vdvalid(IM3H0D,IM3H0M,IM3H0Y) then
  errmsg(2701, {+EN} "Hep B at birth", {EN+}
               {{FR} "Hep B 0", {FR}}
               {{ES} "ES", {ES}}
               IM3H0D,IM3H0M,IM3H0Y);
elseif vdoi(IM3H0D,IM3H0M,IM3H0Y) then
  errmsg(2702, {+EN} "Hep B at birth", {EN+}
               {{FR} "Hep B 0", {FR}}
               {{ES} "ES", {ES}}
               IM3H0D,IM3H0M,IM3H0Y,UF8D,UF8M,UF8Y);
elseif vdob(IM3H0D,IM3H0M,IM3H0Y) then
  errmsg(2703, {+EN} "Hep B at birth", {EN+}
               {{FR} "Hep B 0", {FR}}
               {{ES} "ES", {ES}}
               IM3H0D,IM3H0M,IM3H0Y,AG1D,AG1M,AG1Y);
endif;

PROC IM3H1D
if $ in 0,44,66 then
  skip to IM3H2D;
endif;

PROC IM3H1Y
if vdvalid(IM3H1D,IM3H1M,IM3H1Y) then
  errmsg(2701, {+EN} "Hep B 1", {EN+}
               {{FR} "Hep B 1", {FR}}
               {{ES} "ES", {ES}}
               IM3H1D,IM3H1M,IM3H1Y);
elseif vdoi(IM3H1D,IM3H1M,IM3H1Y) then
  errmsg(2702, {+EN} "Hep B 1", {EN+}
               {{FR} "Hep B 1", {FR}}
               {{ES} "ES", {ES}}
               IM3H1D,IM3H1M,IM3H1Y,UF8D,UF8M,UF8Y);
elseif vdob(IM3H0D,IM3H0M,IM3H0Y) then
  errmsg(2703, {+EN} "Hep B 1", {EN+}
               {{FR} "Hep B 1", {FR}}
               {{ES} "ES", {ES}}
               IM3H1D,IM3H1M,IM3H1Y,AG1D,AG1M,AG1Y);
endif;

PROC IM3H2D
if $ in 0,44,66 then
  skip to IM3H3D;
endif;

PROC IM3H2Y
if vdvalid(IM3H2D,IM3H2M,IM3H2Y) then
  errmsg(2701, {+EN} "Hep B 2", {EN+}
               {{FR} "Hep B 2", {FR}}
               {{ES} "ES", {ES}}
               IM3H2D,IM3H2M,IM3H2Y);
elseif vdoi(IM3H2D,IM3H2M,IM3H2Y) then
  errmsg(2702, {+EN} "Hep B 2", {EN+}
               {{FR} "Hep B 2", {FR}}
               {{ES} "ES", {ES}}
               IM3H2D,IM3H2M,IM3H2Y,UF8D,UF8M,UF8Y);
elseif vdob(IM3H0D,IM3H0M,IM3H0Y) then
  errmsg(2703, {+EN} "Hep B 2", {EN+}
               {{FR} "Hep B 2", {FR}}
               {{ES} "ES", {ES}}
               IM3H2D,IM3H2M,IM3H2Y,AG1D,AG1M,AG1Y);
endif;

PROC IM3H3D
if $ in 0,44,66 then
  skip to IM3MD;
endif;

PROC IM3H3Y
if vdvalid(IM3H3D,IM3H3M,IM3H3Y) then
  errmsg(2701, {+EN} "Hep B 3", {EN+}
               {{FR} "Hep B 3", {FR}}
               {{ES} "ES", {ES}}
               IM3H3D,IM3H3M,IM3H3Y);
elseif vdoi(IM3H3D,IM3H3M,IM3H3Y) then
  errmsg(2702, {+EN} "Hep B 3", {EN+}
               {{FR} "Hep B 3", {FR}}
               {{ES} "ES", {ES}}
               IM3H3D,IM3H3M,IM3H3Y,UF8D,UF8M,UF8Y);
elseif vdob(IM3H3D,IM3H3M,IM3H3Y) then
  errmsg(2703, {+EN} "Hep B 3", {EN+}
               {{FR} "Hep B 3", {FR}}
               {{ES} "ES", {ES}}
               IM3H3D,IM3H3M,IM3H3Y,AG1D,AG1M,AG1Y);
endif;

PROC IM3MD
if $ in 0,44,66 then
  skip to IM3YD;
endif;

PROC IM3MY
if vdvalid(IM3MD,IM3MM,IM3MY) then
  errmsg(2701, {+EN} "Measles (MMR)", {EN+}
               {{FR} "Rougeole", {FR}}
               {{ES} "ES", {ES}}
               IM3MD,IM3MM,IM3MY);
elseif vdoi(IM3MD,IM3MM,IM3MY) then
  errmsg(2702, {+EN} "Measles (MMR)", {EN+}
               {{FR} "Rougeole", {FR}}
               {{ES} "ES", {ES}}
               IM3MD,IM3MM,IM3MY,UF8D,UF8M,UF8Y);
elseif vdob(IM3MD,IM3MM,IM3MY) then
  errmsg(2703, {+EN} "Measles (MMR)", {EN+}
               {{FR} "Rougeole", {FR}}
               {{ES} "ES", {ES}}
               IM3MD,IM3MM,IM3MY,AG1D,AG1M,AG1Y);
endif;

PROC IM3YD
if $ in 0,44,66 then
  skip to IM3VD;
endif;

PROC IM3YY
if vdvalid(IM3YD,IM3YM,IM3YY) then
  errmsg(2701, {+EN} "Yellow Fever", {EN+}
               {{FR} "Fievre Jaune", {FR}}
               {{ES} "ES", {ES}}
               IM3YD,IM3YM,IM3YY);
elseif vdoi(IM3YD,IM3YM,IM3YY) then
  errmsg(2702, {+EN} "Yellow Fever", {EN+}
               {{FR} "Fievre Jaune", {FR}}
               {{ES} "ES", {ES}}
               IM3YD,IM3YM,IM3YY,UF8D,UF8M,UF8Y);
elseif vdob(IM3YD,IM3YM,IM3YY) then
  errmsg(2703, {+EN} "Yellow Fever", {EN+}
               {{FR} "Fievre Jaune", {FR}}
               {{ES} "ES", {ES}}
               IM3YD,IM3YM,IM3YY,AG1D,AG1M,AG1Y);
endif;

PROC IM3VD
if $ in 0,44,66 then
  skip to IM5;
endif;
PROC IM3VY
if vdvalid(IM3VD,IM3VM,IM3VY) then
  errmsg(2701, {+EN} "Vitamin A", {EN+}
               {{FR} "Vitamine A", {FR}}
               {{ES} "ES", {ES}}
               IM3VD,IM3VM,IM3VY);
elseif vdoi(IM3VD,IM3VM,IM3VY) then
  errmsg(2702, {+EN} "Vitamin A", {EN+}
               {{FR} "Vitamine A", {FR}}
               {{ES} "ES", {ES}}
               IM3VD,IM3VM,IM3VY,UF8D,UF8M,UF8Y);
elseif vdob(IM3VD,IM3VM,IM3VY) then
  errmsg(2703, {+EN} "Vitamin A", {EN+}
               {{FR} "Vitamine A", {FR}}
               {{ES} "ES", {ES}}
               IM3VD,IM3VM,IM3VY,AG1D,AG1M,AG1Y);
endif;
PROC IM5
preproc
{IM4 filter}
if !(IM3BD  = 0 or
     IM3P0D = 0 or IM3P1D = 0 or IM3P2D = 0 or IM3P3D = 0 or
                   IM3D1D = 0 or IM3D2D = 0 or IM3D3D = 0 or
     IM3H0D = 0 or IM3H1D = 0 or IM3H2D = 0 or IM3H3D = 0 or
     IM3MD  = 0 or IM3YD  = 0) then
  skip to IM18;
endif;

postproc
if $ = 1 <=>
  (IM3BD  <> 66 and
   IM3P0D <> 66 and IM3P1D <> 66 and IM3P2D <> 66 and IM3P3D <> 66 and
                    IM3D1D <> 66 and IM3D2D <> 66 and IM3D3D <> 66 and
   IM3H0D <> 66 and IM3H1D <> 66 and IM3H2D <> 66 and IM3H3D <> 66 and
   IM3MD  <> 66 and IM3YD  <> 66) then
   errmsg(2710);
   reenter
endif;
skip to IM18;

PROC IM6
if $ <> 1 then
  skip to IM18
endif;

PROC IM8
if $ <> 1 then
  skip to IM11;
endif;

PROC IM11
if $ <> 1 then
  skip to IM13
endif;

PROC IM13
if $ <> 1 then
  skip to IM16
endif;

PROC UF13H
if !inentry and UF9 <> 1
	then endgroup;
endif;
PROC UF13M
if Valid(UF12H) and Valid(UF12M) and Valid(UF13H) and Valid(UF13M) then
  if (UF12H*60+UF12M)>(UF13H*60+UF13M)then
  	errmsg(9990);
   	reenter
  endif;
endif;

PROC FORMAN
if endmess() then
	if AN2 <> 1 then reenter AN2
	else reenter AN5
	endif;
endif;

PROC AN2
if $ <> 1 then
	endgroup;
endif;
PROC AN3
hwsex = HL4(UF4);
hwage = dich - ldob;
if hwsex = 1 then
  recode  hwage : $       => hwerr;
           0- 2 :  0.5- 10.0 => 0;
           3- 5 :  1.0- 13.0 => 0;
           6- 8 :  2.0- 15.0 => 0;
           9-11 :  3.0- 16.5 => 0;
          12-14 :  4.0- 17.5 => 0;
          15-17 :  4.0- 18.5 => 0;
          18-20 :  4.0- 19.5 => 0;
          21-23 :  4.5- 20.5 => 0;
          24-26 :  4.5- 23.0 => 0;
          27-29 :  5.0- 24.0 => 0;
          30-32 :  5.0- 24.5 => 0;
          33-35 :  5.0- 25.5 => 0;
          36-38 :  5.0- 26.0 => 0;
          39-41 :  5.0- 27.0 => 0;
          42-44 :  5.0- 29.0 => 0;
          45-47 :  5.0- 29.0 => 0;
          48-50 :  5.0- 30.0 => 0;
          51-53 :  5.0- 31.0 => 0;
          54-56 :  5.5- 32.0 => 0;
          57-60 :  5.5- 33.0 => 0;
          61-72 :  5.5- 34.0 => 0;
           0-72 :  99.9		 => 0;
                :            => 1;
  endrecode
else
  recode  hwage : $        => hwerr;
           0- 2 :  0.5-  9.0 => 0;
           3- 5 :  1.0- 12.0 => 0;
           6- 8 :  2.0- 14.0 => 0;
           9-11 :  2.5- 15.5 => 0;
          12-14 :  3.0- 16.5 => 0;
          15-17 :  3.5- 17.5 => 0;
          18-20 :  3.5- 18.5 => 0;
          21-23 :  4.0- 19.5 => 0;
          24-26 :  4.5- 21.5 => 0;
          27-29 :  5.0- 23.0 => 0;
          30-32 :  5.0- 24.5 => 0;
          33-35 :  5.0- 25.5 => 0;
          36-38 :  5.0- 27.0 => 0;
          39-41 :  5.0- 29.0 => 0;
          42-44 :  5.5- 29.0 => 0;
          45-47 :  5.5- 30.0 => 0;
          48-50 :  5.5- 31.0 => 0;
          51-53 :  5.5- 32.0 => 0;
          54-56 :  6.0- 33.0 => 0;
          57-60 :  6.0- 34.5 => 0;
          61-72 :  6.0- 36.0 => 0;
           0-72 :  99.9		 => 0;
                :            => 1;
  endrecode
endif;
if hwerr then
  errmsg(2801,hwage)
endif;

PROC AN4A
if hwage >= 24 <=> $ = 1 then
  errmsg(2803)
endif;

PROC AN4
hwsex = HL4(UF4);
hwage = dich - ldob;
if hwsex = 1 then
  recode  hwage : $          => hwerr;
           0- 2 : 36.0- 74.0 => 0;
           3- 5 : 45.0- 83.0 => 0;
           6- 8 : 51.0- 87.0 => 0;
           9-11 : 56.0- 91.0 => 0;
          12-14 : 59.0- 96.0 => 0;
          15-17 : 62.0-100.0 => 0;
          18-20 : 64.0-104.0 => 0;
          21-23 : 65.0-107.0 => 0;
          24-26 : 67.0-109.0 => 0;
          27-29 : 69.0-112.0 => 0;
          30-32 : 70.0-115.0 => 0;
          33-35 : 71.0-119.0 => 0;
          36-38 : 73.0-121.0 => 0;
          39-41 : 74.0-124.0 => 0;
          42-44 : 75.0-127.0 => 0;
          45-47 : 77.0-129.9 => 0;
          48-50 : 79.0-132.0 => 0;
          51-53 : 79.0-134.0 => 0;
          54-56 : 90.0-136.0 => 0;
          57-60 : 82.0-139.0 => 0;
          61-72 : 82.0-140.0 => 0;
           0-72 : 999.9		 => 0;
                :            => 1;
  endrecode
else
  recode  hwage : $          => hwerr;
           0- 2 : 36.0- 72.0 => 0;
           3- 5 : 44.0- 90.0 => 0;
           6- 8 : 50.0- 86.0 => 0;
           9-11 : 54.0- 90.0 => 0;
          12-14 : 57.0- 95.0 => 0;
          15-17 : 60.0- 99.0 => 0;
          18-20 : 62.0-102.0 => 0;
          21-23 : 64.0-106.0 => 0;
          24-26 : 66.0-107.0 => 0;
          27-29 : 69.0-111.0 => 0;
          30-32 : 69.0-114.0 => 0;
          33-35 : 71.0-117.0 => 0;
          36-38 : 72.0-120.0 => 0;
          39-41 : 74.0-122.0 => 0;
          42-44 : 75.0-124.0 => 0;
          45-47 : 77.0-126.9 => 0;
          48-50 : 79.0-129.0 => 0;
          51-53 : 79.0-131.0 => 0;
          54-56 : 81.0-133.0 => 0;
          57-60 : 81.0-136.0 => 0;
          61-72 : 81.0-137.0 => 0;
           0-72 : 999.9		 => 0;
                :            => 1;
  endrecode
endif;
if hwerr then
  errmsg(2802,hwage)
endif;

birthd = AG1D; if AG1D >= 97 then birthd = missing endif;
birthm = AG1M; if AG1M >= 97 then birthm = missing endif;
birthy = AG1Y; if AG1Y >= 9997 then birthy = missing endif;
age = agemth(birthd,birthm,birthy,UF8D,UF8M,UF8Y);
xweight = AN3; if xweight >= 97.0 then xweight = 999.9 endif;
xheight = AN4; if xheight >=997.0 then xheight = 999.9 endif;
x = zsanth(age,HL4(UF4),xweight,xheight,1);

{Commented part that we should consider excluding}
{hap = zshac;
haz = zshaz;
ham = zshap;
wap = zswac;
waz = zswaz;
wam = zswap;
whp = zswhc;
whz = zswhz;
whm = zswhp;
flag = zsflag;}

if $ < 997.0 and age <> 9999 and (ZSFLAG in 1,3,5,7) then
  errmsg(2802,hwage);
endif;

if AN3 <  97.0 and age <> 9999 and (ZSFLAG in 4,5,6,7) then
  errmsg(2801,age);
endif;

if $ < 997.0 and AN3 < 97.0 and (ZSFLAG in 2,3,6,7) then
  errmsg(2804);
endif;

if AN2  = 1 and (AN3 >= 97.0 and $ >= 997.0) then
  errmsg(2805, AN2);
endif;
